@@ -19,17 +19,19 @@
  ***************************************************************************/
 
 #include "kdesvn_part.h"
-#include "svnfrontend/fronthelpers/settings.h"
-#include "svnfrontend/displaysettings_impl.h"
-#include "svnfrontend/dispcolorsettings_impl.h"
-#include "svnfrontend/revisiontreesettingsdlg_impl.h"
-#include "subversionsettings_impl.h"
+#include "src/settings/kdesvnsettings.h"
+#include "settings/displaysettings_impl.h"
+#include "settings/dispcolorsettings_impl.h"
+#include "settings/revisiontreesettingsdlg_impl.h"
+#include "settings/diffmergesettings_impl.h"
+#include "settings/subversionsettings_impl.h"
+#include "settings/cmdexecsettings_impl.h"
 #include "kdesvnview.h"
 #include "commandline_part.h"
-#include "../config.h"
-#include "svnqt/version_check.hpp"
-#include "svnqt/url.hpp"
+#include "src/svnqt/version_check.hpp"
+#include "src/svnqt/url.hpp"
 #include "helpers/ktranslateurl.h"
+#include "helpers/sshagent.h"
 
 #include <kinstance.h>
 #include <kaction.h>
@@ -47,7 +49,9 @@
 #include <qcursor.h>
 #include <qpopupmenu.h>
 
-K_EXPORT_COMPONENT_FACTORY( libkdesvnpart, kdesvnPartFactory )
+//K_EXPORT_COMPONENT_FACTORY( libkdesvnpart, kdesvnPartFactory )
+
+extern "C" { KDESVN_EXPORT void *init_libkdesvnpart() { return new kdesvnPartFactory; } }
 
 static const char version[] = VERSION;
 QString kdesvnPart::m_Extratext = "";
@@ -80,7 +84,7 @@ kdesvnPart::kdesvnPart( QWidget *parentWidget, const char *widgetName,
 #else
     setXMLFile("kdesvn_part.rc");
 #endif
-    connect(m_view,SIGNAL(sigShowPopup(const QString&)),this,SLOT(slotDispPopup(const QString&)));
+    connect(m_view,SIGNAL(sigShowPopup(const QString&,QWidget**)),this,SLOT(slotDispPopup(const QString&,QWidget**)));
     connect(m_view,SIGNAL(sigSwitchUrl(const KURL&)),this,SLOT(openURL(const KURL&)));
     connect(this,SIGNAL(refreshTree()),m_view,SLOT(refreshCurrentTree()));
     connect(m_view,SIGNAL(setWindowCaption(const QString&)),this,SIGNAL(setWindowCaption(const QString&)));
@@ -131,15 +135,9 @@ void kdesvnPart::slotFileProperties()
 {
 }
 
-void kdesvnPart::slotDispPopup(const QString&name)
+void kdesvnPart::slotDispPopup(const QString&name,QWidget**target)
 {
-    QWidget *w = hostContainer(name);
-    QPopupMenu *popup = static_cast<QPopupMenu *>(w);
-    if (!popup) {
-        kdDebug()<<"Error getting popupMenu"<<endl;
-        return;
-    }
-    popup->exec(QCursor::pos());
+    *target = hostContainer(name);
 }
 
 KAboutData* kdesvnPart::createAboutData()
@@ -168,18 +166,19 @@ void kdesvnPart::setupActions()
     KToggleAction *toggletemp;
     toggletemp = new KToggleAction(i18n("Use \"Kompare\" for displaying diffs"),KShortcut(),
             actionCollection(),"toggle_use_kompare");
-    toggletemp->setChecked(Settings::use_kompare_for_diff());
+    toggletemp->setChecked(Kdesvnsettings::use_kompare_for_diff());
     connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotUseKompare(bool)));
 
     toggletemp = new KToggleAction(i18n("Logs follow node changes"),KShortcut(),
             actionCollection(),"toggle_log_follows");
-    toggletemp->setChecked(Settings::log_follows_nodes());
+    toggletemp->setChecked(Kdesvnsettings::log_follows_nodes());
     connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotLogFollowNodes(bool)));
 
     toggletemp = new KToggleAction(i18n("Display ignored files"),KShortcut(),
             actionCollection(),"toggle_ignored_files");
-    toggletemp->setChecked(Settings::display_ignored_files());
+    toggletemp->setChecked(Kdesvnsettings::display_ignored_files());
     connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotDisplayIgnored(bool)));
+
 #if 0
     /// not needed this moment
     toggletemp = new KToggleAction(i18n("Display unknown files"),KShortcut(),
@@ -200,14 +199,19 @@ void kdesvnPart::setupActions()
     actionCollection()->setHighlightingEnabled(true);
 }
 
+void kdesvnPart::slotSshAdd()
+{
+    SshAgent ag;
+    ag.addSshIdentities(true);
+}
 
 /*!
     \fn kdesvnPart::slotLogFollowNodes(bool)
  */
 void kdesvnPart::slotLogFollowNodes(bool how)
 {
-    Settings::setLog_follows_nodes(how);
-    Settings::writeConfig();
+    Kdesvnsettings::setLog_follows_nodes(how);
+    Kdesvnsettings::writeConfig();
 }
 
 
@@ -216,8 +220,8 @@ void kdesvnPart::slotLogFollowNodes(bool how)
  */
 void kdesvnPart::slotDisplayIgnored(bool how)
 {
-    Settings::setDisplay_ignored_files(how);
-    Settings::writeConfig();
+    Kdesvnsettings::setDisplay_ignored_files(how);
+    Kdesvnsettings::writeConfig();
     emit refreshTree();
 }
 
@@ -240,8 +244,8 @@ void kdesvnPart::slotDisplayUnkown(bool )
 void kdesvnPart::slotUseKompare(bool how)
 {
     int selected = how ? 1 : 0;
-    Settings::setUse_kompare_for_diff(selected);
-    Settings::writeConfig();
+    Kdesvnsettings::setUse_kompare_for_diff(selected);
+    Kdesvnsettings::writeConfig();
 }
 
 
@@ -324,16 +328,21 @@ void kdesvnPart::slotShowSettings()
     }
     KConfigDialog *dialog = new KConfigDialog(widget(),
          "kdesvnpart_settings",
-         Settings::self(),
+         Kdesvnsettings::self(),
          KDialogBase::IconList);
+    dialog->setHelp("setup","kdesvn");
     dialog->addPage(new DisplaySettings_impl(0,"general_items"),
         i18n("General"),"configure",i18n("General"),true);
     dialog->addPage(new SubversionSettings_impl(0,"subversion_items"),
         i18n("Subversion"),"kdesvn",i18n("Subversion Settings"),true);
+    dialog->addPage(new DiffMergeSettings_impl(0,"diffmerge_items"),
+        i18n("Diff & Merge"),"kdesvnmerge",i18n("Settings for diff and merge"),true);
     dialog->addPage(new DispColorSettings_impl(0,"color_items"),
         i18n("Colors"),"colorize",i18n("Color Settings"),true);
     dialog->addPage(new RevisiontreeSettingsDlg_impl(0,"revisiontree_items"),
         i18n("Revision tree"),"configure",i18n("Revision tree Settings"),true);
+    dialog->addPage(new CmdExecSettings_impl(0,"cmdexec_items"),
+        "KIO/"+i18n("Commandline"),"terminal",i18n("Settings for commandline and KIO execution"),true);
 
     connect(dialog,SIGNAL(settingsChanged()),this,SLOT(slotSettingsChanged()));
     connect(this,SIGNAL(settingsChanged()),widget(),SLOT(slotSettingsChanged()));
@@ -349,15 +358,15 @@ void kdesvnPart::slotSettingsChanged()
     KAction * temp;
     temp = actionCollection()->action("toggle_use_kompare");
     if (temp) {
-        ((KToggleAction*)temp)->setChecked(Settings::use_kompare_for_diff()==1);
+        ((KToggleAction*)temp)->setChecked(Kdesvnsettings::use_kompare_for_diff()==1);
     }
     temp = actionCollection()->action("toggle_log_follows");
     if (temp) {
-        ((KToggleAction*)temp)->setChecked(Settings::log_follows_nodes());
+        ((KToggleAction*)temp)->setChecked(Kdesvnsettings::log_follows_nodes());
     }
     temp = actionCollection()->action("toggle_ignored_files");
     if (temp) {
-        ((KToggleAction*)temp)->setChecked(Settings::display_ignored_files());
+        ((KToggleAction*)temp)->setChecked(Kdesvnsettings::display_ignored_files());
     }
 #if 0
     /// not needed this momenta
@@ -379,6 +388,7 @@ KParts::Part* cFactory::createPartObject( QWidget *parentWidget, const char *wid
                                                         QObject *parent, const char *name,
                                                         const char *classname, const QStringList &args )
 {
+    Q_UNUSED(classname);
     // Create an instance of our Part
     kdesvnPart* obj = new kdesvnPart( parentWidget, widgetName, parent, name, args );
     return obj;
