@@ -21,6 +21,8 @@
 #ifndef _KDESVNPART_H_
 #define _KDESVNPART_H_
 
+#include "kdesvn-config.h"
+
 #include <kparts/part.h>
 #include <kparts/genericfactory.h>
 #include <kparts/factory.h>
@@ -41,7 +43,7 @@ class KAboutApplication;
  * @author Rajko Albrecht <rajko.albrecht@tecways.com>
  * @version 0.1
  */
-class kdesvnPart : public KParts::ReadOnlyPart
+class KDESVN_EXPORT kdesvnPart : public KParts::ReadOnlyPart
 {
     Q_OBJECT
 public:
@@ -63,9 +65,10 @@ signals:
     void settingsChanged();
 
 public slots:
-    virtual void slotDispPopup(const QString&);
+    virtual void slotDispPopup(const QString&,QWidget**target);
     virtual void slotFileProperties();
     virtual bool openURL(const KURL&);
+    virtual void slotSshAdd();
 
 protected:
     /**
@@ -98,7 +101,7 @@ class commandline_part;
 class KCmdLineArgs;
 
 /* we make it ourself 'cause we will enhance a little bit! */
-class cFactory : public KParts::Factory
+class KDESVN_EXPORT cFactory : public KParts::Factory
 {
     Q_OBJECT
 public:
@@ -119,7 +122,7 @@ private:
 
 typedef cFactory kdesvnPartFactory;
 
-class KdesvnBrowserExtension : public KParts::BrowserExtension
+class KPARTS_EXPORT KdesvnBrowserExtension : public KParts::BrowserExtension
 {
     Q_OBJECT
 public:
