@@ -18,16 +18,17 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "config.h"
+#include "kdesvn-config.h"
 #include "kdesvnd_dcop.h"
-#include "authdialogimpl.h"
-#include "ssltrustprompt_impl.h"
-#include "logmsg_impl.h"
-#include "svnqt/client.hpp"
-#include "svnqt/revision.hpp"
-#include "svnqt/status.hpp"
-#include "svnqt/context_listener.hpp"
-#include "svnqt/url.hpp"
+#include "src/ksvnwidgets/authdialogimpl.h"
+#include "src/ksvnwidgets/ssltrustprompt_impl.h"
+#include "src/ksvnwidgets/logmsg_impl.h"
+#include "src/settings/kdesvnsettings.h"
+#include "src/svnqt/client.hpp"
+#include "src/svnqt/revision.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/context_listener.hpp"
+#include "src/svnqt/url.hpp"
 #include "helpers/ktranslateurl.h"
 
 #include <kdebug.h>
@@ -40,12 +41,7 @@
 #include <qdir.h>
 
 extern "C" {
-// avoid problems with elder kde installations
-#ifdef __KDE_HAVE_GCC_VISIBILITY
-    KDE_EXPORT KDEDModule *create_kdesvnd(const QCString &name)
-#else
-    KDEDModule *create_kdesvnd(const QCString &name)
-#endif
+    KDESVN_EXPORT KDEDModule *create_kdesvnd(const QCString &name)
     {
        return new kdesvnd_dcop(name);
     }
@@ -81,11 +77,12 @@ public:
     virtual bool contextSslClientCertPrompt (QString & certFile);
     virtual bool contextSslClientCertPwPrompt (QString & password,
                                                const QString & realm, bool & maySave);
+    virtual void contextProgress(long long int current, long long int max);
     /* context listener virtuals end */
 
 protected:
     svn::Client* m_Svnclient;
-    svn::Context* m_CurrentContext;
+    svn::ContextP m_CurrentContext;
 };
 
 IListener::IListener(kdesvnd_dcop*p)
@@ -100,31 +97,42 @@ IListener::IListener(kdesvnd_dcop*p)
 
 IListener::~IListener()
 {
-    delete m_CurrentContext;
 }
 
 kdesvnd_dcop::kdesvnd_dcop(const QCString&name) : KDEDModule(name)
 {
-    kdDebug() << "Starting new service... " << endl;
     KGlobal::locale()->insertCatalogue("kdesvn");
     m_Listener=new IListener(this);
 }
 
 kdesvnd_dcop::~kdesvnd_dcop()
 {
-    kdDebug() << "Going away... " << endl;
     delete m_Listener;
 }
 
-QStringList kdesvnd_dcop::getTopLevelActionMenu (const KURL::List list)
+QStringList kdesvnd_dcop::getActionMenu (const KURL::List list)
 {
     QStringList result;
-    if (list.count()==0) {
+    Kdesvnsettings::self()->readConfig();
+    if (Kdesvnsettings::no_konqueror_contextmenu()||list.count()==0) {
         return result;
     }
     QString base;
-    if (!isWorkingCopy(list[0],base)) {
-        if (isRepository(list[0])) {
+
+
+    bool parentIsWc = false;
+    bool itemIsWc = isWorkingCopy(list[0],base);
+    bool itemIsRepository = false;
+
+    QString _par = list[0].directory(true,true);
+    parentIsWc = isWorkingCopy(_par,base);
+
+    if (!parentIsWc && !itemIsWc) {
+        itemIsRepository = isRepository(list[0]);
+    }
+
+    if (!itemIsWc) {
+        if (itemIsRepository) {
             result << "Export"
                    << "Checkout";
         } else {
@@ -133,33 +141,18 @@ QStringList kdesvnd_dcop::getTopLevelActionMenu (const KURL::List list)
         }
     } else {
         result << "Update"
-            << "Commit";
+               << "Commit";
     }
-    return result;
-}
-
-QStringList kdesvnd_dcop::getActionMenu (const KURL::List list)
-{
-    QStringList result;
-    if (list.count()==0) {
-        return result;
-    }
-    QString base;
-
-    bool parentIsWc = false;
-    bool itemIsWc = isWorkingCopy(list[0],base);
-
-    QString _par = list[0].directory(true,true);
-    parentIsWc = isWorkingCopy(_par,base);
 
     if (!parentIsWc && !itemIsWc) {
-        if (isRepository(list[0])) {
+        if (itemIsRepository) {
             result << "Log"
                     << "Info";
             if (isRepository(list[0].upURL())) {
                 result << "Blame"
                         << "Rename";
             }
+            result << "Tree";
         }
         return result;
     }
@@ -170,6 +163,7 @@ QStringList kdesvnd_dcop::getActionMenu (const KURL::List list)
     }
 
     result << "Log"
+        << "Tree"
         << "Info"
         << "Diff"
         << "Rename"
@@ -196,9 +190,9 @@ QStringList kdesvnd_dcop::getSingleActionMenu(QCString what)
     return getActionMenu(l);
 }
 
-QStringList kdesvnd_dcop::get_login(QString realm)
+QStringList kdesvnd_dcop::get_login(QString realm,QString user)
 {
-    AuthDialogImpl auth(realm);
+    AuthDialogImpl auth(realm,user);
     QStringList res;
     if (auth.exec()==QDialog::Accepted) {
         res.append(auth.Username());
@@ -321,7 +315,7 @@ bool IListener::contextGetLogin (const QString & realm,
                                   QString & password,
                                   bool & maySave)
 {
-    QStringList res = m_back->get_login(realm);
+    QStringList res = m_back->get_login(realm,username);
     if (res.count()!=3) {
         return false;
     }
@@ -399,3 +393,7 @@ bool IListener::contextSslClientCertPwPrompt (QString & password,
 {
     return false;
 }
+
+void IListener::contextProgress(long long int, long long int)
+{
+}
