@@ -22,6 +22,7 @@
 #ifndef _KDESVNVIEW_H_
 #define _KDESVNVIEW_H_
 
+#include "src/svnqt/repositorylistener.hpp"
 #include <qwidget.h>
 #include <kparts/part.h>
 
@@ -47,7 +48,7 @@ class KTextBrowser;
  * @author Rajko Albrecht <ral@alwins-world.de>
  * @version 0.1
  */
-class kdesvnView : public QWidget
+class kdesvnView : public QWidget,public svn::repository::RepositoryListener
 {
     Q_OBJECT
 public:
@@ -76,10 +77,10 @@ public:
      */
     virtual bool openURL(const KURL& url);
 
-    /**
-     * Print this view to any medium -- paper or not
-     */
-    void print(QPainter *, int height, int width);
+    /* repositorylistener methods */
+    virtual void sendWarning(const QString&);
+    virtual void sendError(const QString&);
+    virtual bool isCanceld();
 
 signals:
     /**
@@ -92,16 +93,28 @@ signals:
      */
     void signalChangeCaption(const QString&);
 
-    void sigShowPopup(const QString&);
+    void sigShowPopup(const QString&,QWidget**);
     void sigSwitchUrl(const KURL&);
     void setWindowCaption(const QString&);
     void sigUrlChanged(const QString&);
+    void sigMakeBaseDirs();
+
+    /* repositorylistener methods */
+    void tickProgress();
+    void waitShow(bool);
 
 public slots:
     virtual void closeMe();
-    virtual void slotDispPopup(const QString&);
+    virtual void slotDispPopup(const QString&,QWidget**);
     virtual void refreshCurrentTree();
     virtual void slotSettingsChanged();
+    virtual void slotCreateRepo();
+    virtual void slotDumpRepo();
+    virtual void slotHotcopy();
+    virtual void slotLoaddump();
+
+    /* repositorylistener methods */
+    virtual void setCanceled(bool);
 
 protected slots:
     virtual void slotOnURL(const QString& url);
@@ -113,9 +126,12 @@ protected:
     kdesvnfilelist*m_flist;
     KActionCollection*m_Collection;
 
-    QSplitter* m_Splitter;
+    QSplitter *m_Splitter,*m_treeSplitter;
     QString m_currentURL;
     KTextBrowser*m_LogWindow;
+protected:
+    virtual void setupActions();
+    bool m_ReposCancel;
 };
 
 #endif // _KDESVNVIEW_H_
