@@ -303,10 +303,10 @@ void KioListener::contextNotify (const char * path,
         default:
             break;
     }
-    par->setMetaData(QString::number(counter()).rightJustify( 10,'0' )+ "path" , QString::fromUtf8( path ));
+    par->setMetaData(QString::number(counter()).rightJustify( 10,'0' )+ "path" , QString::FROMUTF8( path ));
     par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "action", QString::number( action ));
     par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "kind", QString::number( kind ));
-    par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "mime_t", QString::fromUtf8( mime_type ));
+    par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "mime_t", QString::FROMUTF8( mime_type ));
     par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "content", QString::number( content_state ));
     par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "prop", QString::number( prop_state ));
     par->setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "rev", QString::number( revision ));
@@ -409,8 +409,9 @@ bool KioListener::contextGetLogin (const QString & realm,
 
     QDataStream stream(params,IO_WriteOnly);
     stream << realm;
+    stream << username;
 
-    if (!par->dcopClient()->call("kded","kdesvnd","get_login(QString)",params,replyType,reply)) {
+    if (!par->dcopClient()->call("kded","kdesvnd","get_login(QString,QString)",params,replyType,reply)) {
         kdWarning()<<"Communication with dcop failed"<<endl;
         return false;
     }
@@ -430,3 +431,14 @@ bool KioListener::contextGetLogin (const QString & realm,
     maySave = lt[2]=="true";
     return true;
 }
+
+
+/*!
+    \fn KioListener::contextProgress(long long int current, long long int max)
+ */
+void KioListener::contextProgress(long long int cur, long long int max)
+{
+    if (par) {
+        par->contextProgress(cur,max);
+    }
+}
