@@ -17,18 +17,18 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#include "config.h"
+#include "kdesvn-config.h"
 #include "kiosvn.h"
 #include "kiolistener.h"
 
-#include "svnfrontend/svnactions.h"
-#include "svnfrontend/dummydisplay.h"
-#include "svnqt/dirent.hpp"
-#include "svnqt/url.hpp"
-#include "svnqt/status.hpp"
-#include "svnqt/targets.hpp"
-#include "svnqt/info_entry.hpp"
-#include "helpers/sub2qt.h"
+#include "src/svnqt/dirent.hpp"
+#include "src/svnqt/url.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/targets.hpp"
+#include "src/svnqt/info_entry.hpp"
+#include "src/settings/kdesvnsettings.h"
+#include "src/helpers/sub2qt.h"
+#include "src/helpers/sshagent.h"
 
 #include <stdlib.h>
 #include <math.h>
@@ -71,7 +71,8 @@ public:
 
     KioListener m_Listener;
     bool first_done;
-    svn::Context* m_CurrentContext;
+    bool dispProgress;
+    svn::ContextP m_CurrentContext;
     svn::Client* m_Svnclient;
 
     svn::Revision urlToRev(const KURL&);
@@ -83,6 +84,7 @@ KioSvnData::KioSvnData(kio_svnProtocol*par)
 {
     m_Svnclient=svn::Client::getobject(0,0);
     m_CurrentContext = 0;
+    dispProgress = false;
     reInitClient();
 }
 
@@ -91,8 +93,10 @@ void KioSvnData::reInitClient()
     if (first_done) {
         return;
     }
+    SshAgent ag;
+    ag.querySshAgent();
+
     first_done = true;
-    delete m_CurrentContext;
     m_CurrentContext = new svn::Context();
     m_CurrentContext->setListener(&m_Listener);
     m_Svnclient->setContext(m_CurrentContext);
@@ -101,12 +105,20 @@ void KioSvnData::reInitClient()
 KioSvnData::~KioSvnData()
 {
     delete m_Svnclient;
-    delete m_CurrentContext;
 }
 
 svn::Revision KioSvnData::urlToRev(const KURL&url)
 {
     QMap<QString,QString> q = url.queryItems();
+
+    /* we try to check if it is ssh and try to get a password for it */
+    QString proto = url.protocol();
+
+    if (proto.find("ssh")!=-1) {
+        SshAgent ag;
+        ag.addSshIdentities();
+    }
+
     svn::Revision rev,tmp;
     rev = svn::Revision::UNDEFINED;
     if (q.find("rev")!=q.end()) {
@@ -117,7 +129,7 @@ svn::Revision KioSvnData::urlToRev(const KURL&url)
 }
 
 kio_svnProtocol::kio_svnProtocol(const QCString &pool_socket, const QCString &app_socket)
-    : SlaveBase("kio_ksvn", pool_socket, app_socket)
+    : SlaveBase("kio_ksvn", pool_socket, app_socket),StreamWrittenCb()
 {
     m_pData=new KioSvnData(this);
     KGlobal::locale()->insertCatalogue("kdesvn");
@@ -130,12 +142,7 @@ kio_svnProtocol::~kio_svnProtocol()
 
 extern "C"
 {
-// avoid problems with elder kde installations
-#ifdef __KDE_HAVE_GCC_VISIBILITY
-    KDE_EXPORT int kdemain(int argc, char **argv);
-#else
-    int kdemain(int argc, char **argv);
-#endif
+    KDESVN_EXPORT int kdemain(int argc, char **argv);
 }
 
 int kdemain(int argc, char **argv)
@@ -178,13 +185,13 @@ void kio_svnProtocol::listDir(const KURL&url)
     } catch (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
-        error(KIO::ERR_CANNOT_ENTER_DIRECTORY,"");
+        error(KIO::ERR_CANNOT_ENTER_DIRECTORY,ex);
         return;
     }
     KIO::UDSEntry entry;
     totalSize(dlist.size());
     for (unsigned int i=0; i < dlist.size();++i) {
-        QDateTime dt = helpers::sub2qt::apr_time2qt(dlist[i].time());
+        QDateTime dt = svn::DateTime(dlist[i].time());
         if (createUDSEntry(dlist[i].name(),
             dlist[i].lastAuthor(),
             dlist[i].size(),
@@ -207,6 +214,7 @@ void kio_svnProtocol::stat(const KURL& url)
         rev = svn::Revision::HEAD;
     }
     svn::Revision peg = rev;
+    bool dummy = false;
     QString s = makeSvnUrl(url);
     svn::InfoEntries e;
     try {
@@ -217,18 +225,24 @@ void kio_svnProtocol::stat(const KURL& url)
         error( KIO::ERR_SLAVE_DEFINED,ex);
         return;
     }
+
     if (e.count()==0) {
-        finished();
-        return;
+        dummy = true;
+/*        finished();
+        return;*/
     }
 
     KIO::UDSEntry entry;
     QDateTime dt;
-    dt = helpers::sub2qt::apr_time2qt(e[0].cmtDate());
-    if (e[0].kind()==svn_node_file) {
-        createUDSEntry(url.filename(),"",0,false,dt.toTime_t(),entry);
-    } else {
+    if (dummy) {
         createUDSEntry(url.filename(),"",0,true,dt.toTime_t(),entry);
+    } else {
+        dt = svn::DateTime(e[0].cmtDate());
+        if (e[0].kind()==svn_node_file) {
+            createUDSEntry(url.filename(),"",0,false,dt.toTime_t(),entry);
+        } else {
+            createUDSEntry(url.filename(),"",0,true,dt.toTime_t(),entry);
+        }
     }
     statEntry(entry);
     finished();
@@ -241,9 +255,9 @@ void kio_svnProtocol::get(const KURL& url)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    QByteArray content;
+    KioByteStream dstream(this,url.filename());
     try {
-        content = m_pData->m_Svnclient->cat(makeSvnUrl(url),rev,rev);
+        m_pData->m_Svnclient->cat(dstream,makeSvnUrl(url),rev,rev);
     } catch (svn::ClientException e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
@@ -251,32 +265,25 @@ void kio_svnProtocol::get(const KURL& url)
         finished();
         return;
     }
-    KMimeType::Ptr mt = KMimeType::findByContent(content);
-    kdDebug(0) << "KMimeType returned : " << mt->name() << endl;
-    mimeType( mt->name() );
-    totalSize(content.size());
-    //send data
-    data(content);
+    totalSize(dstream.written());
     data(QByteArray()); // empty array means we're done sending the data
     finished();
 }
 
 void kio_svnProtocol::mkdir(const KURL &url, int)
 {
-    kdDebug()<<"kio_svn::get "<< url << endl;
-    //m_pData->reInitClient();
+    kdDebug()<<"kio_svn::mkdir "<< url << endl;
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    QString msg;
     svn::Path p(makeSvnUrl(url));
     try {
-        m_pData->m_Svnclient->mkdir(p,msg);
+        m_pData->m_Svnclient->mkdir(p,getDefaultLog());
     }catch (svn::ClientException e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
-    kdDebug()<<"kio_svn::get finished " << url << endl;
+    kdDebug()<<"kio_svn::mkdir finished " << url << endl;
     finished();
 }
 
@@ -284,6 +291,7 @@ void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
 {
     kdDebug()<<"kio_svn::rename "<< src << " to " << target <<  endl;
     QString msg;
+    m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),force);
     }catch (svn::ClientException e) {
@@ -295,23 +303,28 @@ void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
 
 void kio_svnProtocol::copy(const KURL&src,const KURL&dest,int permissions,bool overwrite)
 {
+    Q_UNUSED(permissions);
+    Q_UNUSED(overwrite);
     kdDebug()<<"kio_svn::copy "<< src << " to " << dest <<  endl;
     svn::Revision rev = m_pData->urlToRev(src);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    QString msg;
+    m_pData->dispProgress=true;
+    m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         m_pData->m_Svnclient->copy(makeSvnUrl(src),rev,makeSvnUrl(dest));
     }catch (svn::ClientException e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
+    m_pData->dispProgress=false;
     kdDebug()<<"kio_svn::copy finished" <<  endl;
     finished();
 }
 
 void kio_svnProtocol::del(const KURL&src,bool isfile)
 {
+    Q_UNUSED(isfile);
     kdDebug()<<"kio_svn::del "<< src << endl;
     //m_pData->reInitClient();
     svn::Revision rev = m_pData->urlToRev(src);
@@ -319,6 +332,7 @@ void kio_svnProtocol::del(const KURL&src,bool isfile)
         rev = svn::Revision::HEAD;
     }
     svn::Targets target(makeSvnUrl(src));
+    m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         m_pData->m_Svnclient->remove(target,false);
     } catch (svn::ClientException e) {
@@ -705,7 +719,7 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
     svn::Revision r2(rnum2,rstring2);
     QString u1 = makeSvnUrl(uri1);
     QString u2 = makeSvnUrl(uri2);
-    QString ex = "";
+    QByteArray ex;
     KTempDir tdir;
     tdir.setAutoDelete(true);
     /// @todo read settings for diff (ignore contentype)
@@ -716,9 +730,52 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
     }
-    QTextIStream stream(&ex);
+    QString out = QString::FROMUTF8(ex);
+    QTextIStream stream(&out);
     while (!stream.atEnd()) {
         setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "diffresult",stream.readLine());
         m_pData->m_Listener.incCounter();
     }
 }
+void kio_svnProtocol::streamWritten(const KIO::filesize_t current)
+{
+    processedSize(current);
+}
+
+void kio_svnProtocol::streamSendMime(KMimeMagicResult* mt)
+{
+    if (mt) {
+        mimeType(mt->mimeType());
+    }
+}
+
+void kio_svnProtocol::streamPushData(QByteArray array)
+{
+    data(array);
+}
+
+void kio_svnProtocol::contextProgress(long long int current, long long int)
+{
+    if (m_pData->dispProgress) {
+        processedSize(current);
+    }
+}
+
+void kio_svnProtocol::streamTotalSizeNull()
+{
+    totalSize(0);
+}
+
+
+/*!
+    \fn kio_svnProtocol::getDefaultLog()
+ */
+QString kio_svnProtocol::getDefaultLog()
+{
+    QString res = QString::null;
+    Kdesvnsettings::self()->readConfig();
+    if (Kdesvnsettings::kio_use_standard_logmsg()) {
+        res = Kdesvnsettings::kio_standard_logmsg();
+    }
+    return res;
+}
