@@ -20,6 +20,8 @@
 #ifndef KIOSVN_H
 #define KIOSVN_H
 
+#include "kiobytestream.h"
+
 #include <qstring.h>
 #include <qcstring.h>
 #include <kurl.h>
@@ -36,7 +38,7 @@ class KioSvnData;
 /**
 @author Rajko Albrecht
 */
-class kio_svnProtocol : public KIO::SlaveBase
+class kio_svnProtocol : public KIO::SlaveBase,public StreamWrittenCb
 {
 public:
     kio_svnProtocol(const QCString &pool_socket, const QCString &app_socket);
@@ -80,6 +82,12 @@ public:
         SVN_DIFF=13
     };
 
+    void contextProgress(long long int current, long long int max);
+    virtual void streamWritten(const KIO::filesize_t current);
+    virtual void streamPushData(QByteArray);
+    virtual void streamSendMime(KMimeMagicResult*mt);
+    virtual void streamTotalSizeNull();
+
 protected:
     virtual void commit(const KURL::List&);
     virtual void status(const KURL&,bool,bool);
@@ -90,5 +98,7 @@ private:
     bool createUDSEntry( const QString& filename, const QString& user, long long int size, bool isdir, time_t mtime, KIO::UDSEntry& entry);
     static QString makeSvnUrl(const KURL&url);
     bool getLogMsg(QString&);
+protected:
+    QString getDefaultLog();
 };
 #endif
