@@ -18,9 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include "ccontextlistener.h"
-#include "authdialogimpl.h"
-#include "logmsg_impl.h"
-#include "ssltrustprompt_impl.h"
+#include "src/ksvnwidgets/authdialogimpl.h"
+#include "src/ksvnwidgets/logmsg_impl.h"
+#include "src/ksvnwidgets/ssltrustprompt_impl.h"
 
 #include <klocale.h>
 #include <kapp.h>
@@ -129,7 +129,7 @@ bool CContextListener::contextGetLogin (
 {
     emit waitShow(true);
     emit sendNotify(realm);
-    AuthDialogImpl auth(realm);
+    AuthDialogImpl auth(realm,username);
     if (auth.exec()==QDialog::Accepted) {
         username=auth.Username();
         password=auth.Password();
@@ -163,7 +163,7 @@ void CContextListener::contextNotify (const char *path,
 
     if (!aString.isEmpty()) {
         QTextStream ts(&msg,IO_WriteOnly);
-        ts << NotifyAction(action) << " " << QString::fromUtf8(path);
+        ts << NotifyAction(action) << " " << QString::FROMUTF8(path);
         if (revision>-1) {
             ts << " (Rev "<<revision<<")";
         }
@@ -307,4 +307,12 @@ QString CContextListener::translate(const QString&what)
     return i18n(what);
 }
 
+/*!
+    \fn CContextListener::contextProgress(long long int current, long long int max)
+ */
+void CContextListener::contextProgress(long long int current, long long int max)
+{
+    emit netProgress(current,max);
+}
+
 #include "ccontextlistener.moc"
