@@ -20,8 +20,8 @@
 #ifndef CCONTEXTLISTENER_H
 #define CCONTEXTLISTENER_H
 
-#include "svnqt/context_listener.hpp"
-#include "helpers/smart_pointer.h"
+#include "src/svnqt/context_listener.hpp"
+#include "src/svnqt/smart_pointer.hpp"
 
 #include <qobject.h>
 #include <qstring.h>
@@ -31,7 +31,7 @@ class CContextListenerData;
 /**
 @author Rajko Albrecht
 */
-class CContextListener : public QObject, public svn::ContextListener,public ref_count
+class CContextListener : public QObject, public svn::ContextListener,public svn::ref_count
 {
     Q_OBJECT
 public:
@@ -69,14 +69,17 @@ public:
     static QString NotifyAction(svn_wc_notify_action_t action);
     static QString NotifyState(svn_wc_notify_state_t);
 
-    void setCanceled(bool how);
-
     static QStringList failure2Strings(apr_uint32_t acceptedFailures);
+    virtual void contextProgress(long long int current, long long int max);
+
+public slots:
+    virtual void setCanceled(bool);
 
 signals:
     void sendNotify(const QString&);
     void tickProgress();
     void waitShow(bool);
+    void netProgress(long long int, long long int);
 
 protected:
     static const int smax_actionstring;
