@@ -18,23 +18,26 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include "commandexec.h"
-#include "fronthelpers/settings.h"
+#include "src/settings/kdesvnsettings.h"
 #include "svnfrontend/svnactions.h"
 #include "svnfrontend/dummydisplay.h"
-#include "svnqt/targets.hpp"
-#include "svnqt/url.hpp"
-#include "svnqt/dirent.hpp"
-#include "helpers/sub2qt.h"
-#include "helpers/ktranslateurl.h"
-#include "svnfrontend/fronthelpers/rangeinput_impl.h"
-#include "svnfrontend/copymoveview_impl.h"
+#include "src/svnqt/targets.hpp"
+#include "src/svnqt/url.hpp"
+#include "src/svnqt/dirent.hpp"
+#include "src/helpers/sub2qt.h"
+#include "src/helpers/ktranslateurl.h"
+#include "src/helpers/sshagent.h"
+#include "src/svnfrontend/fronthelpers/rangeinput_impl.h"
+#include "src/svnfrontend/copymoveview_impl.h"
 
+#include <kapp.h>
 #include <kglobal.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kdialogbase.h>
+#include <ktextbrowser.h>
 
 #include <qfile.h>
 #include <qtextstream.h>
@@ -78,7 +81,7 @@ pCPart::pCPart()
     Stdout.setDevice(&toStdout);
     Stderr.setDevice(&toStderr);
     disp = new DummyDisplay();
-    m_SvnWrapper = new SvnActions(disp);
+    m_SvnWrapper = new SvnActions(disp,0,true);
 }
 
 pCPart::~pCPart()
@@ -92,6 +95,8 @@ CommandExec::CommandExec(QObject*parent, const char *name,KCmdLineArgs *args)
 {
     m_pCPart = new pCPart;
     m_pCPart->args = args;
+    SshAgent ag;
+    ag.querySshAgent();
 
     connect(m_pCPart->m_SvnWrapper,SIGNAL(clientException(const QString&)),this,SLOT(clientException(const QString&)));
     connect(m_pCPart->m_SvnWrapper,SIGNAL(sendNotify(const QString&)),this,SLOT(slotNotifyMessage(const QString&)));
@@ -109,6 +114,8 @@ int CommandExec::exec()
     if (!m_pCPart->args) {
         return -1;
     }
+    m_lastMessages = "";
+    m_lastMessagesLines = 0;
     m_pCPart->m_SvnWrapper->reInitClient();
     bool dont_check_second = false;
     bool dont_check_all = false;
@@ -187,6 +194,8 @@ int CommandExec::exec()
         slotCmd=SLOT(slotCmd_addnew());
     } else if (!QString::compare(m_pCPart->cmd,"switch")) {
         slotCmd=SLOT(slotCmd_switch());
+    } else if (!QString::compare(m_pCPart->cmd,"tree")) {
+        slotCmd=SLOT(slotCmd_tree());
     }
 
     bool found = connect(this,SIGNAL(executeMe()),this,slotCmd.ascii());
@@ -203,7 +212,7 @@ int CommandExec::exec()
     QString mainProto;
     QString _baseurl;
     for (int j = 2; j<m_pCPart->args->count();++j) {
-        tmpurl = helpers::KTranslateUrl::translateSystemUrl(m_pCPart->args->url(j));
+        tmpurl = helpers::KTranslateUrl::translateSystemUrl(m_pCPart->args->url(j).prettyURL());
         query = tmpurl.query();
         q = m_pCPart->args->url(j).queryItems();
         if (q.find("rev")!=q.end()) {
@@ -212,12 +221,18 @@ int CommandExec::exec()
             v = "";
         }
         tmpurl.setProtocol(svn::Url::transformProtokoll(tmpurl.protocol()));
-        kdDebug()<<"Urlpath: " << tmpurl.path()<<endl;
+        if (tmpurl.protocol().find("ssh")!=-1) {
+            SshAgent ag;
+            // this class itself checks if done before
+            ag.addSshIdentities();
+        }
+        m_pCPart->extraRevisions[j-2]=svn::Revision::HEAD;
 
         if (tmpurl.isLocalFile() && (j==2 || !dont_check_second) && !dont_check_all) {
             if (m_pCPart->m_SvnWrapper->isLocalWorkingCopy("file://"+tmpurl.path(),_baseurl)) {
                 tmp = tmpurl.path();
                 m_pCPart->baseUrls[j-2]=_baseurl;
+                m_pCPart->extraRevisions[j-2]=svn::Revision::WORKING;
                 if (j==2) mainProto = "";
             } else {
                 tmp = "file://"+tmpurl.path();
@@ -242,18 +257,13 @@ int CommandExec::exec()
             tmp.truncate(tmp.length()-1);
         }
         m_pCPart->url.append(tmp);
-        kdDebug()<<"Resulting url: "<<tmp<<endl;
         if ( (j>2 && dont_check_second) || dont_check_all) {
             continue;
         }
-        svn::Revision re,ra;
-        m_pCPart->m_SvnWrapper->svnclient()->url2Revision(v,re,ra);
-
-        if (re != svn::Revision::UNDEFINED) {
-            kdDebug()<<"Revision " << re << " gefunden. " << endl;
+        svn::Revision re = v;
+        if (re) {
             m_pCPart->extraRevisions[j-2]=re;
         }
-        kdDebug()<<"Uri zum testen: " << tmpurl<<endl;
     }
     if (m_pCPart->url.count()==0) {
         m_pCPart->url.append(".");
@@ -280,6 +290,22 @@ int CommandExec::exec()
     }
 
     emit executeMe();
+    if (Kdesvnsettings::self()->cmdline_show_logwindow() &&
+        m_lastMessagesLines >= Kdesvnsettings::self()->cmdline_log_minline()) {
+        KDialogBase dlg (
+            KApplication::activeModalWidget(),
+            "execution_log",
+            true,
+            i18n("Execution log"),
+            KDialogBase::Ok);
+
+        QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
+        KTextBrowser*ptr = new KTextBrowser(Dialog1Layout);
+        ptr->setText(m_lastMessages);
+        dlg.resize(dlg.configDialogSize(*(Kdesvnsettings::self()->config()),"kdesvn_cmd_log"));
+        dlg.exec();
+        dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),"kdesvn_cmd_log",false);
+    }
     return 0;
 }
 
@@ -306,10 +332,24 @@ void CommandExec::slotCmd_log()
     if (m_pCPart->start == svn::Revision::UNDEFINED) {
         m_pCPart->start = 1;
     }
-    bool list = Settings::self()->log_always_list_changed_files();
+    bool list = Kdesvnsettings::self()->log_always_list_changed_files();
     m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start,m_pCPart->end,m_pCPart->url[0],list,m_pCPart->log_limit);
 }
 
+/*!
+    \fn CommandExec::slotCmdLog
+ */
+void CommandExec::slotCmd_tree()
+{
+    if (m_pCPart->end == svn::Revision::UNDEFINED) {
+        m_pCPart->end = svn::Revision::HEAD;
+    }
+    if (m_pCPart->start == svn::Revision::UNDEFINED) {
+        m_pCPart->start = 1;
+    }
+    m_pCPart->m_SvnWrapper->makeTree(m_pCPart->url[0],m_pCPart->extraRevisions[0],m_pCPart->start,m_pCPart->end);
+}
+
 void CommandExec::slotCmd_checkout()
 {
     m_pCPart->m_SvnWrapper->CheckoutExport(m_pCPart->url[0],false);
@@ -332,10 +372,10 @@ void CommandExec::slotCmd_exportto()
 
 void CommandExec::slotCmd_blame()
 {
-    if (m_pCPart->end == svn::Revision::UNDEFINED) {
+    if (!m_pCPart->end) {
         m_pCPart->end = svn::Revision::HEAD;
     }
-    if (m_pCPart->start == svn::Revision::UNDEFINED) {
+    if (!m_pCPart->start) {
         m_pCPart->start = 1;
     }
     m_pCPart->m_SvnWrapper->makeBlame(m_pCPart->start,m_pCPart->end,m_pCPart->url[0]);
@@ -348,12 +388,10 @@ void CommandExec::slotCmd_cat()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for cat"<<endl;
     }
-    kdDebug()<<"Rev set "<<m_pCPart->rev_set<<endl;
-    m_pCPart->m_SvnWrapper->makeCat(
+    m_pCPart->m_SvnWrapper->slotMakeCat(
         (m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0],m_pCPart->url[0]
-        ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
+        ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),0);
 }
 
 void CommandExec::slotCmd_get()
@@ -363,22 +401,13 @@ void CommandExec::slotCmd_get()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for get";
     }
     if (!m_pCPart->outfile_set || m_pCPart->outfile.isEmpty()) {
         clientException(i18n("\"GET\" requires output file!"));
         return;
     }
-    QFile of(m_pCPart->outfile);
-    if (!of.open(IO_WriteOnly)) {
-        clientException(i18n("Could not open %1 for writing").arg(m_pCPart->outfile));
-        return;
-    }
-    QByteArray content = m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0]
-        ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
-    if (!content.size()||of.writeBlock(content,content.size())==-1) {
-        clientException(i18n("Error getting content and/or writing it to %1").arg(m_pCPart->outfile));
-    }
+    m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0], m_pCPart->outfile,
+        (m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
 
 void CommandExec::slotCmd_update()
@@ -391,11 +420,10 @@ void CommandExec::slotCmd_diff()
 {
     if (m_pCPart->url.count()==1) {
         if (!m_pCPart->rev_set && !svn::Url::isValid(m_pCPart->url[0])) {
-            kdDebug()<<"Local diff" << endl;
-            m_pCPart->start = svn::Revision::UNDEFINED;
-            m_pCPart->end = svn::Revision::UNDEFINED;
+            m_pCPart->start = svn::Revision::WORKING;
+            m_pCPart->end = svn::Revision::BASE;
         }
-        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0],m_pCPart->start,m_pCPart->end);
+        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0],m_pCPart->start,m_pCPart->url[0],m_pCPart->end);
     } else {
         svn::Revision r1 = svn::Revision::HEAD;
         svn::Revision r2 = svn::Revision::HEAD;
@@ -434,11 +462,17 @@ void CommandExec::slotCmd_commit()
 void CommandExec::slotCmd_list()
 {
     svn::DirEntries res;
-    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->url[0],res,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),false)) {
+    svn::Revision rev = m_pCPart->end;
+    if (m_pCPart->rev_set){
+        rev = m_pCPart->start;
+    } else if (m_pCPart->extraRevisions[0]) {
+        rev = m_pCPart->extraRevisions[0];
+    }
+    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->url[0],res,rev,false)) {
         return;
     }
     for (unsigned int i = 0; i < res.count();++i) {
-        QString d = helpers::sub2qt::apr_time2qt(res[i].time()).toString(QString("yy-MM-dd hh:mm::ss"));
+        QString d = svn::DateTime(res[i].time()).toString(QString("yyyy-MM-dd hh:mm::ss"));
         m_pCPart->Stdout
             << (res[i].kind()==svn_node_dir?"D":"F")<<" "
             << d << " "
@@ -464,7 +498,6 @@ void CommandExec::slotCmd_copy()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for copy"<<endl;
     }
     m_pCPart->m_SvnWrapper->makeCopy(m_pCPart->url[0],target,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
@@ -511,21 +544,27 @@ void CommandExec::slotCmd_addnew()
  */
 bool CommandExec::scanRevision()
 {
-    /// @todo scan for date-ranges, too.
     QString revstring = m_pCPart->args->getOption("r");
     QStringList revl = QStringList::split(":",revstring);
     if (revl.count()==0) {
         return false;
     }
-    m_pCPart->m_SvnWrapper->svnclient()->url2Revision(revstring,m_pCPart->start,m_pCPart->end);
+    m_pCPart->start = revl[0];
+    if (revl.count()>1) {
+        m_pCPart->end = revl[1];
+    }
     m_pCPart->rev_set=true;
     return true;
 }
 
 void CommandExec::slotNotifyMessage(const QString&msg)
 {
-    //m_pCPart->Stdout << msg << endl;
     m_pCPart->m_SvnWrapper->slotExtraLogMsg(msg);
+    if (Kdesvnsettings::self()->cmdline_show_logwindow()) {
+        ++m_lastMessagesLines;
+        if (!m_lastMessages.isEmpty()) m_lastMessages.append("\n");
+        m_lastMessages.append(msg);
+    }
 }
 
 bool CommandExec::askRevision()
