@@ -64,6 +64,7 @@ protected slots:
     virtual void slotCmd_add();
     virtual void slotCmd_revert();
     virtual void slotCmd_addnew();
+    virtual void slotCmd_tree();
 
 signals:
     void executeMe();
@@ -71,6 +72,9 @@ protected:
     virtual bool scanRevision();
     virtual bool askRevision();
 
+    QString m_lastMessages;
+    unsigned int m_lastMessagesLines;
+
 private:
     pCPart*m_pCPart;
 
