@@ -41,27 +41,27 @@ EditProperty_impl::EditProperty_impl(QWidget *parent, const char *name)
     fileProperties += ("svn:mime-type");
 
     fileComments += i18n("One of <b>'native'</b>, <b>'LF'</b>, <b>'CR'</b>, <b>'CRLF'</b></b>.");
-    fileComments += i18n("If present, make the file executable.<br>\
-        This property can not be set on a directory.\
-        A non-recursive attempt will fail, and a recursive attempt\
-        will set the property only on the file children of the folder.");
-    fileComments += i18n("Keywords to be expanded into the contents of a file.<br>\
-        They can be inserted into documents by placing a keyword anchor\
-        which is formatted as $KeywordName$.<br>\
-        Valid keywords are:<br>\
-        <b>URL/HeadURL</b> The URL for the head revision of the project.<br>\
-        <b>Author/LastChangedBy</b> The last person to change the file.<br>\
-        <b>Date/LastChangedDate</b> The date/time the object was last modified.<br>\
-        <b>Revision/Rev/LastChangedRevision</b> The last revision the object changed.<br>\
-        <b>Id</b> A compressed summary of the previous 4 keywords.");
-    fileComments += i18n("Set this to any value (e.g. <b>'*'</b>) to enforce locking for this file.<br>\
-        The file will be set read-only when checked out or updated,\
-        indicating that a user must acquire a lock on the file before\
-        they can edit and commit changes.");
-    fileComments += i18n("The mimetype of the file. Used to determine\
-        whether to merge the file and how to serve it from\
-        Apache. A mimetype beginning with <b>'text/'</b> (or an absent\
-        mimetype) is treated as text. Anything else is treated as binary.");
+    fileComments += i18n("If present, make the file executable.<br>"
+        "This property can not be set on a directory. "
+        "A non-recursive attempt will fail, and a recursive attempt "
+        "will set the property only on the file children of the folder.");
+    fileComments += i18n("Keywords to be expanded into the contents of a file.<br>"
+        "They can be inserted into documents by placing a keyword anchor "
+        "which is formatted as $KeywordName$.<br>"
+        "Valid keywords are:<br>"
+        "<b>URL/HeadURL</b> The URL for the head revision of the project.<br>"
+        "<b>Author/LastChangedBy</b> The last person to change the file.<br>"
+        "<b>Date/LastChangedDate</b> The date/time the object was last modified.<br>"
+        "<b>Revision/Rev/LastChangedRevision</b> The last revision the object changed.<br>"
+        "<b>Id</b> A compressed summary of the previous 4 keywords.");
+    fileComments += i18n("Set this to any value (e.g. <b>'*'</b>) to enforce locking for this file.<br>"
+        "The file will be set read-only when checked out or updated, "
+        "indicating that a user must acquire a lock on the file before "
+        "they can edit and commit changes.");
+    fileComments += i18n("The mimetype of the file. Used to determine "
+        "whether to merge the file and how to serve it from "
+        "Apache. A mimetype beginning with <b>'text/'</b> (or an absent "
+        "mimetype) is treated as text. Anything else is treated as binary.");
 
     dirProperties += ("svn:eol-style");
     dirProperties += ("svn:executable");
@@ -77,40 +77,40 @@ EditProperty_impl::EditProperty_impl(QWidget *parent, const char *name)
     dirProperties += ("bugtraq:logregex");
 
     dirComments += i18n("One of <b>'native'</b>, <b>'LF'</b>, <b>'CR'</b>, <b>'CRLF'</b></b>.");
-    dirComments += i18n("If present, make the file executable.<br>\
-        This property can not be set on a directory.\
-        A non-recursive attempt will fail, and a recursive attempt\
-        will set the property only on the file children of the folder.");
-    dirComments += i18n("A newline separated list of module specifiers, each of\
-        which consists of a relative directory path, optional revision\
-        flags, and an URL. For example:<br>\
-        <nobr><b>foo http://example.com/repos/projectA</b></nobr><br>\
-        <nobr><b>foo/bar -r 1234 http://example.com/repos/projectB</b></nobr>");
+    dirComments += i18n("If present, make the file executable.<br>"
+        "This property can not be set on a directory. "
+        "A non-recursive attempt will fail, and a recursive attempt "
+        "will set the property only on the file children of the folder.");
+    dirComments += i18n("A newline separated list of module specifiers, each of "
+        "which consists of a relative directory path, optional revision "
+        "flags, and an URL. For example:<br>"
+        "<nobr><b>foo http://example.com/repos/projectA</b></nobr><br>"
+        "<nobr><b>foo/bar -r 1234 http://example.com/repos/projectB</b></nobr>");
     dirComments += i18n("A newline separated list of file patterns to ignore.");
-    dirComments += i18n("The mimetype of the file. Used to determine\
-        whether to merge the file and how to serve it from\
-        Apache. A mimetype beginning with <b>'text/'</b> (or an absent\
-        mimetype) is treated as text. Anything else is treated as binary.");
+    dirComments += i18n("The mimetype of the file. Used to determine "
+        "whether to merge the file and how to serve it from "
+        "Apache. A mimetype beginning with <b>'text/'</b> (or an absent "
+        "mimetype) is treated as text. Anything else is treated as binary.");
     dirComments += i18n("Label text to show for the edit box where the user enters the issue number.");
-    dirComments += i18n("URL pointing to the issue tracker. It must contain\
-        <b>%BUGID%</b> which gets replaced with the bug issue number. Example:<br>\
-        <nobr><b>http://example.com/mantis/view.php?id=%BUGID%</b></nobr>");
-    dirComments += i18n("String which is appended to a log message when an issue\
-        number is entered. The string must contain <b>%BUGID%</b>\
-        which gets replaced with the bug issue number.");
-    dirComments += i18n("Set to <b>'yes'</b> if a warning shall be shown when\
-        no issue is entered in the commit dialog. Possible values:<br>\
-        <b>'true'</b>/<b>'yes'</b> or <b>'false'</b>/<b>'no'</b>");
-    dirComments += i18n("Set to <b>'false'</b> if your bugtracking system has\
-        issues which are referenced not by numbers.<br>\
-        Possible values: <b>'true'</b> or <b>'false'</b>");
-    dirComments += i18n("Set to <b>'false'</b> if you want the bugtracking ID\
-        to be inserted at the top of the log message. The\
-        default is <b>'true'</b> which means the bugtracking\
-        ID is appended to the log message.");
-    dirComments += i18n("Two regular expressions separated by a newline.<br>\
-        The first expression is used to find a string referring to an issue, the\
-        second expression is used to extract the bare bug ID from that string.");
+    dirComments += i18n("URL pointing to the issue tracker. It must contain "
+        "<b>%BUGID%</b> which gets replaced with the bug issue number. Example:<br>"
+        "<nobr><b>http://example.com/mantis/view.php?id=%BUGID%</b></nobr>");
+    dirComments += i18n("String which is appended to a log message when an issue "
+        "number is entered. The string must contain <b>%BUGID%</b> "
+        "which gets replaced with the bug issue number.");
+    dirComments += i18n("Set to <b>'yes'</b> if a warning shall be shown when "
+        "no issue is entered in the commit dialog. Possible values:<br>"
+        "<b>'true'</b>/<b>'yes'</b> or <b>'false'</b>/<b>'no'</b>");
+    dirComments += i18n("Set to <b>'false'</b> if your bugtracking system has "
+        "issues which are referenced not by numbers.<br>"
+        "Possible values: <b>'true'</b> or <b>'false'</b>");
+    dirComments += i18n("Set to <b>'false'</b> if you want the bugtracking ID"
+        "to be inserted at the top of the log message. The "
+        "default is <b>'true'</b> which means the bugtracking "
+        "ID is appended to the log message.");
+    dirComments += i18n("Two regular expressions separated by a newline.<br>"
+        "The first expression is used to find a string referring to an issue, the "
+        "second expression is used to extract the bare bug ID from that string.");
 
     m_NameEdit->setAutoCompletion(true);
     m_NameEdit->setCompletionMode(KGlobalSettings::CompletionPopupAuto);
