@@ -19,12 +19,12 @@
  ***************************************************************************/
 #include "filelistviewitem.h"
 #include "kdesvnfilelist.h"
-#include "fronthelpers/settings.h"
+#include "src/settings/kdesvnsettings.h"
 #include "helpers/sub2qt.h"
-#include "svnqt/status.hpp"
-#include "svnqt/revision.hpp"
-#include "svnqt/exception.hpp"
-#include "svnqt/url.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/revision.hpp"
+#include "src/svnqt/exception.hpp"
+#include "src/svnqt/url.hpp"
 
 #include <klocale.h>
 #include <kiconloader.h>
@@ -80,7 +80,10 @@ void FileListViewItem::init()
 void FileListViewItem::setOpen(bool o)
 {
     if (o && childCount()==0) {
-        m_Ksvnfilelist->slotItemClicked(this);
+        m_Ksvnfilelist->setEnabled( false );
+        m_Ksvnfilelist->slotItemRead(this);
+        m_Ksvnfilelist->setEnabled( true );
+        m_Ksvnfilelist->setFocus();
     }
     KListViewItem::setOpen(o);
 }
@@ -126,8 +129,8 @@ void FileListViewItem::refreshStatus(bool childs,QPtrList<SvnItem>*exclude,bool
 
 void FileListViewItem::makePixmap()
 {
-    int size = Settings::listview_icon_size();
-    bool overlay = Settings::display_overlays();
+    int size = Kdesvnsettings::listview_icon_size();
+    bool overlay = Kdesvnsettings::display_overlays();
     QPixmap pm;
     if (m_Pixmap.isNull()) {
         pm = getPixmap(size,overlay);
@@ -141,8 +144,8 @@ void FileListViewItem::setPreviewPix(const QPixmap& pixmap)
 {
     if (pixmap.isNull()) return;
     m_Pixmap = pixmap;
-    int size = Settings::listview_icon_size();
-    bool overlay = Settings::display_overlays();
+    int size = Kdesvnsettings::listview_icon_size();
+    bool overlay = Kdesvnsettings::display_overlays();
     QPixmap pm = getPixmap(pixmap,size,overlay);
     setPixmap(COL_ICON,pm);
 }
@@ -186,7 +189,15 @@ int FileListViewItem::compare( QListViewItem* item, int col, bool ascending ) co
     if (col==COL_LAST_REV) {
         return k->cmtRev()-cmtRev();
     }
-    return text(col).localeAwareCompare(k->text(col));
+
+    if (Kdesvnsettings::case_sensitive_sort()) {
+        if (Kdesvnsettings::locale_is_casesensitive()) {
+            return text(col).localeAwareCompare(k->text(col));
+        }
+        return text(col).compare(k->text(col));
+    } else {
+        return text(col).lower().localeAwareCompare(k->text(col).lower());
+    }
 }
 
 void FileListViewItem::removeChilds()
@@ -214,7 +225,7 @@ void FileListViewItem::updateStatus(const svn::Status&s)
 
 void FileListViewItem::paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment)
 {
-    bool colors = Settings::colored_state();
+    bool colors = Kdesvnsettings::colored_state();
     if (!colors||m_bgColor==NONE) {
         KListViewItem::paintCell(p,cg,column,width,alignment);
         return;
@@ -223,31 +234,31 @@ void FileListViewItem::paintCell(QPainter *p, const QColorGroup &cg, int column,
     QColor _bgColor;
     switch(m_bgColor) {
         case UPDATES:
-            _bgColor = Settings::color_need_update();
+            _bgColor = Kdesvnsettings::color_need_update();
             break;
         case  LOCKED:
-            _bgColor = Settings::color_locked_item();
+            _bgColor = Kdesvnsettings::color_locked_item();
             break;
         case  ADDED:
-            _bgColor = Settings::color_item_added();
+            _bgColor = Kdesvnsettings::color_item_added();
             break;
         case  DELETED:
-            _bgColor = Settings::color_item_deleted();
+            _bgColor = Kdesvnsettings::color_item_deleted();
             break;
         case  MODIFIED:
-            _bgColor = Settings::color_changed_item();
+            _bgColor = Kdesvnsettings::color_changed_item();
             break;
         case MISSING:
-            _bgColor = Settings::color_missed_item();
+            _bgColor = Kdesvnsettings::color_missed_item();
             break;
         case NOTVERSIONED:
-            _bgColor = Settings::color_notversioned_item();
+            _bgColor = Kdesvnsettings::color_notversioned_item();
             break;
         case CONFLICT:
-            _bgColor = Settings::color_conflicted_item();
+            _bgColor = Kdesvnsettings::color_conflicted_item();
             break;
         case NEEDLOCK:
-            _bgColor = Settings::color_need_lock();
+            _bgColor = Kdesvnsettings::color_need_lock();
             break;
         default:
             KListViewItem::paintCell(p,cg,column,width,alignment);
