@@ -24,7 +24,7 @@
 #include <klistview.h>
 #include <qdatetime.h>
 #include <qptrlist.h>
-#include "svnqt/status.hpp"
+#include "src/svnqt/status.hpp"
 
 class QPainter;
 class KFileItem;
