@@ -19,7 +19,8 @@
  ***************************************************************************/
 #include "checkoutinfo_impl.h"
 #include "rangeinput_impl.h"
-#include "svnqt/url.hpp"
+#include "src/svnqt/url.hpp"
+#include "helpers/ktranslateurl.h"
 #include <kurlrequester.h>
 #include <qlabel.h>
 #include <klineedit.h>
@@ -52,7 +53,7 @@ QString CheckoutInfo_impl::reposURL()
     } else {
         uri.setProtocol(proto);
     }
-    return uri.url();
+    return uri.prettyURL();
 }
 
 QString CheckoutInfo_impl::targetDir()
@@ -87,23 +88,16 @@ void CheckoutInfo_impl::setTargetUrl(const QString&what)
 void CheckoutInfo_impl::setStartUrl(const QString&what)
 {
     KURL uri(what);
-    kdDebug()<<"What: "<<what << " URL: "<<uri<<endl;
     if (uri.protocol()=="file") {
         if (what.startsWith("file:")) {
             uri.setProtocol("ksvn+file");
         } else {
             uri.setProtocol("");
         }
-    } else if (uri.protocol()=="http") {
-        uri.setProtocol("ksvn+http");
-    } else if (uri.protocol()=="https") {
-        uri.setProtocol("ksvn+https");
-    } else if (uri.protocol()=="svn") {
-        uri.setProtocol("ksvn");
-    } else if (uri.protocol()=="svn+ssh") {
-        uri.setProtocol("ksvn+ssh");
+    } else {
+        uri.setProtocol(helpers::KTranslateUrl::makeKdeUrl(uri.protocol()));
     }
-    m_UrlEdit->setURL(uri.url());
+    m_UrlEdit->setURL(uri.prettyURL());
 }
 
 void CheckoutInfo_impl::disableForce(bool how)
