@@ -20,8 +20,8 @@
 #ifndef CHECKOUTINFO_IMPL_H
 #define CHECKOUTINFO_IMPL_H
 
-#include "src/svnfrontend/fronthelpers/checkoutinfo.h"
-#include "svnqt/revision.hpp"
+#include "checkoutinfo.h"
+#include "src/svnqt/revision.hpp"
 #include "kurl.h"
 
 class CheckoutInfo_impl: public CheckoutInfo {
