@@ -20,8 +20,8 @@
 #ifndef RANGEINPUT_IMPL_H
 #define RANGEINPUT_IMPL_H
 
-#include "src/svnfrontend/fronthelpers/rangeinput.h"
-#include "svnqt/revision.hpp"
+#include "rangeinput.h"
+#include "src/svnqt/revision.hpp"
 #include <qpair.h>
 
 class Rangeinput_impl: public RangeInputDlg {
