@@ -21,9 +21,9 @@
 #include "graphtreelabel.h"
 #include "pannerview.h"
 #include "graphtree_defines.h"
-#include "../fronthelpers/settings.h"
+#include "src/settings/kdesvnsettings.h"
 #include "../stopdlg.h"
-#include "svnqt/client.hpp"
+#include "src/svnqt/client.hpp"
 
 #include <kapp.h>
 #include <kdebug.h>
@@ -32,11 +32,13 @@
 #include <kprocess.h>
 #include <klocale.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 
 #include <qtooltip.h>
 #include <qwmatrix.h>
 #include <qpopupmenu.h>
 #include <qpainter.h>
+#include <qregexp.h>
 
 #include <math.h>
 
@@ -74,7 +76,7 @@ void GraphViewTip::maybeTip( const QPoint & pos)
     }
 }
 
-RevGraphView::RevGraphView(CContextListener*aListener,svn::Client*_client,QWidget * parent, const char * name, WFlags f)
+RevGraphView::RevGraphView(QObject*aListener,svn::Client*_client,QWidget * parent, const char * name, WFlags f)
  : QCanvasView(parent,name,f)
 {
     m_Canvas = 0L;
@@ -99,6 +101,7 @@ RevGraphView::RevGraphView(CContextListener*aListener,svn::Client*_client,QWidge
     m_LastAutoPosition = TopLeft;
     _isMoving = false;
     _noUpdateZoomerPos = false;
+    m_LabelMap[""]="";
 }
 
 RevGraphView::~RevGraphView()
@@ -161,12 +164,15 @@ void RevGraphView::endInsert()
 
 void RevGraphView::readDotOutput(KProcess*,char *   buffer,int   buflen)
 {
-    dotOutput+=QString::fromLatin1(buffer, buflen);
+    dotOutput+=QString::fromLocal8Bit(buffer, buflen);
 }
 
 void RevGraphView::dotExit(KProcess*p)
 {
     if (p!=renderProcess)return;
+    // remove line breaks when lines to long
+    QRegExp endslash("\\\\\\n");
+    dotOutput.replace(endslash,"");
     double scale = 1.0, scaleX = 1.0, scaleY = 1.0;
     double dotWidth, dotHeight;
     QTextStream* dotStream;
@@ -183,7 +189,7 @@ void RevGraphView::dotExit(KProcess*p)
         if (line.isEmpty()) continue;
         QTextStream lineStream(line, IO_ReadOnly);
         lineStream >> cmd;
-        if (cmd == "stop") break;
+        if (cmd == "stop") {break; }
 
         if (cmd == "graph") {
             lineStream >> scale >> dotWidth >> dotHeight;
@@ -207,23 +213,16 @@ void RevGraphView::dotExit(KProcess*p)
         }
         if (cmd=="node") {
             QString nodeName, label;
+            QString _x,_y,_w,_h;
             double x, y, width, height;
-            lineStream >> nodeName >> x >> y >> width >> height;
-            QChar c;
-            lineStream >> c;
-            while (c.isSpace()) lineStream >> c;
-            if (c != '\"') {
-              lineStream >> label;
-              label = c + label;
-            } else {
-                lineStream >> c;
-                while(!c.isNull() && (c != '\"')) {
-                //if (c == '\\') lineStream >> c;
-                    label += c;
-                    lineStream >> c;
-                }
-            }
-
+            lineStream >> nodeName >> _x >> _y >> _w >> _h;
+            x=_x.toDouble();
+            y=_y.toDouble();
+            width=_w.toDouble();
+            height=_h.toDouble();
+            // better here 'cause dot may scramble utf8 labels so we regenerate it better
+            // and do not read it in.
+            label = getLabelstring(nodeName);
             int xx = (int)(scaleX * x + _xMargin);
             int yy = (int)(scaleY * (dotHeight - y) + _yMargin);
             int w = (int)(scaleX * width);
@@ -239,15 +238,18 @@ void RevGraphView::dotExit(KProcess*p)
             m_NodeList[nodeName]=t;
         } else {
             QString node1Name, node2Name, label;
+            QString _x,_y;
             double x, y;
             QPointArray pa;
             int points, i;
             lineStream >> node1Name >> node2Name;
             lineStream >> points;
             pa.resize(points);
-            for (i=0;i<points;i++) {
+            for (i=0;i<points;++i) {
                 if (lineStream.atEnd()) break;
-                lineStream >> x >> y;
+                lineStream >> _x >> _y;
+                x=_x.toDouble();
+                y=_y.toDouble();
                 int xx = (int)(scaleX * x + _xMargin);
                 int yy = (int)(scaleY * (dotHeight - y) + _yMargin);
 
@@ -372,29 +374,69 @@ QColor RevGraphView::getBgColor(const QString&nodeName)const
     }
     switch (it.data().Action) {
         case 'D':
-            res = Settings::tree_delete_color();
+            res = Kdesvnsettings::tree_delete_color();
             break;
         case 'M':
-            res = Settings::tree_modify_color();
+            res = Kdesvnsettings::tree_modify_color();
             break;
         case 'A':
-            res = Settings::tree_add_color();
+            res = Kdesvnsettings::tree_add_color();
             break;
         case 'C':
         case 1:
-            res = Settings::tree_copy_color();
+            res = Kdesvnsettings::tree_copy_color();
             break;
         case 'R':
         case 2:
-            res = Settings::tree_rename_color();
+            res = Kdesvnsettings::tree_rename_color();
             break;
         default:
-            res = Settings::tree_modify_color();
+            res = Kdesvnsettings::tree_modify_color();
             break;
     }
     return res;
 }
 
+const QString&RevGraphView::getLabelstring(const QString&nodeName)
+{
+    QMap<QString,QString>::ConstIterator nIt;
+    nIt = m_LabelMap.find(nodeName);
+    if (nIt!=m_LabelMap.end()) {
+        return nIt.data();
+    }
+    trevTree::ConstIterator it1;
+    it1 = m_Tree.find(nodeName);
+    if (it1==m_Tree.end()) {
+        return m_LabelMap[""];
+    }
+    QString res;
+    switch (it1.data().Action) {
+    case 'D':
+        res = i18n("Deleted at revision %1").arg(it1.data().rev);
+    break;
+    case 'A':
+        res = i18n("Added at revision %1 as %2")
+            .arg(it1.data().rev)
+            .arg(it1.data().name);
+    break;
+    case 'C':
+    case 1:
+        res = i18n("Copied to %1 at revision %2").arg(it1.data().name).arg(it1.data().rev);
+    break;
+    case 2:
+        res = i18n("Renamed to %1 at revision %2").arg(it1.data().name).arg(it1.data().rev);
+    break;
+    case 'M':
+        res = i18n("Modified at revision %1").arg(it1.data().rev);
+    break;
+    default:
+        res=i18n("Revision %1").arg(it1.data().rev);
+    break;
+    }
+    m_LabelMap[nodeName]=res;
+    return m_LabelMap[nodeName];
+}
+
 void RevGraphView::dumpRevtree()
 {
     delete dotTmpFile;
@@ -411,7 +453,7 @@ void RevGraphView::dumpRevtree()
 
     *stream << "digraph \"callgraph\" {\n";
     *stream << "  bgcolor=\"transparent\";\n";
-    int dir = Settings::tree_direction();
+    int dir = Kdesvnsettings::tree_direction();
     *stream << QString("  rankdir=\"");
     switch (dir) {
         case 3:
@@ -434,32 +476,12 @@ void RevGraphView::dumpRevtree()
 
     RevGraphView::trevTree::ConstIterator it1;
     for (it1=m_Tree.begin();it1!=m_Tree.end();++it1) {
-        *stream << "  " << it1.key().latin1()
-            << "[ ";
-            //"[label=\""<< it1.data().name.latin1() << "\", ";
-//        *stream << "fontname=\"serif\", ";
-        *stream << "shape=box, ";
-        if (it1.data().Action=='D') {
-            *stream << "label=\"Deleted at Revision "<<it1.data().rev
-                << "\",";
-        } else if (it1.data().Action=='A') {
-            *stream << "label=\"Added at Revision "<<it1.data().rev
-                    << " " << it1.data().name.latin1() << " "
-                    <<"\",";
-        } else if (it1.data().Action=='C'||it1.data().Action==(char)1){
-            *stream << "label=\"Copy to "<< it1.data().name.latin1()
-                    << " at Rev " << it1.data().rev
-                    <<"\",";
-        } else if (it1.data().Action=='R'||it1.data().Action==(char)2){
-            *stream << "label=\"Renamed to "<< it1.data().name.latin1()
-                    << " at Rev " << it1.data().rev
-                    <<"\",";
-        } else {
-            *stream << "label=\"Modified at Revision "<<it1.data().rev<<"\",";
-        }
-        *stream << "];\n";
-        for (unsigned j=0;j
-        <it1.data().targets.count();++j) {
+        *stream << "  " << it1.key()
+            << "[ "
+            << "shape=box, "
+            << "label=\""<<getLabelstring(it1.key())<<"\","
+            << "];\n";
+        for (unsigned j=0;j<it1.data().targets.count();++j) {
             *stream<<"  "<<it1.key().latin1()<< " "
                 << "->"<<" "<<it1.data().targets[j].key
                 << " [fontsize=10,style=\"solid\"];\n";
@@ -467,17 +489,18 @@ void RevGraphView::dumpRevtree()
     }
     *stream << "}\n"<<flush;
     renderProcess = new KProcess();
+    renderProcess->setEnvironment("LANG","C");
     *renderProcess << "dot";
     *renderProcess << dotTmpFile->name() << "-Tplain";
     connect(renderProcess,SIGNAL(processExited(KProcess*)),this,SLOT(dotExit(KProcess*)));
     connect(renderProcess,SIGNAL(receivedStdout(KProcess*,char*,int)),
         this,SLOT(readDotOutput(KProcess*,char*,int)) );
     if (!renderProcess->start(KProcess::NotifyOnExit,KProcess::Stdout)) {
-        QString error = i18n("Could not start process \"");
+        QString arguments;
         for (unsigned c=0;c<renderProcess->args().count();++c) {
-            error+=QString(" %1").arg(renderProcess->args()[c]);
+            arguments+=QString(" %1").arg(renderProcess->args()[c]);
         }
-        error+=" \".";
+        QString error = i18n("Could not start process \"%1\".").arg(arguments);
         showText(error);
         renderProcess=0;
         //delete renderProcess;<
@@ -517,7 +540,7 @@ QString RevGraphView::toolTip(const QString&_nodename,bool full)const
 
     if (!full) {
         res+=QString("<b>%1</b>").arg(it.data().name);
-        res += i18n("<br>Revision: %2<br>Author: %3<br>Date: %4<br>Log:%5</html>")
+        res += i18n("<br>Revision: %1<br>Author: %2<br>Date: %3<br>Log:%4</html>")
             .arg(it.data().rev)
             .arg(it.data().Author)
             .arg(it.data().Date)
@@ -728,7 +751,7 @@ void RevGraphView::contentsMousePressEvent ( QMouseEvent * e )
     _lastPos = e->globalPos();
 }
 
-void RevGraphView::contentsMouseReleaseEvent ( QMouseEvent * e )
+void RevGraphView::contentsMouseReleaseEvent ( QMouseEvent * )
 {
     _isMoving = false;
     updateZoomerPos();
@@ -750,7 +773,7 @@ void RevGraphView::setNewDirection(int dir)
 {
     if (dir<0)dir=3;
     else if (dir>3)dir=0;
-    Settings::setTree_direction(dir);
+    Kdesvnsettings::setTree_direction(dir);
     dumpRevtree();
 }
 
@@ -769,6 +792,9 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
             && getAction(((GraphTreeLabel*)i)->nodename())!='D') {
             popup.insertItem(i18n("Diff to selected item"),302);
         }
+        if (getAction(((GraphTreeLabel*)i)->nodename())!='D') {
+            popup.insertItem(i18n("Cat this version"),303);
+        }
         if (m_Selected == i) {
             popup.insertItem(i18n("Unselect item"),401);
         } else {
@@ -781,6 +807,9 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
     popup.insertItem(i18n("Rotate counter-clockwise"),101);
     popup.insertItem(i18n("Rotate clockwise"),102);
     popup.insertSeparator();
+    int it = popup.insertItem(i18n("Diff in revisiontree is recursive"),202);
+    popup.setCheckable(true);
+    popup.setItemChecked(it,Kdesvnsettings::tree_diff_rec());
     popup.insertItem(i18n("Save tree as png"),201);
 
     int r = popup.exec(e->globalPos());
@@ -788,13 +817,13 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
     switch (r) {
         case 101:
         {
-            int dir = Settings::tree_direction();
+            int dir = Kdesvnsettings::tree_direction();
             setNewDirection(++dir);
         }
         break;
         case 102:
         {
-            int dir = Settings::tree_direction();
+            int dir = Kdesvnsettings::tree_direction();
             setNewDirection(--dir);
         }
         break;
@@ -822,6 +851,11 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
                 }
             }
         }
+        case 202:
+        {
+            Kdesvnsettings::setTree_diff_rec(!Kdesvnsettings::tree_diff_rec());
+            break;
+        }
         break;
         case 301:
             if (i && i->rtti()==GRAPHTREE_LABEL && !((GraphTreeLabel*)i)->source().isEmpty()) {
@@ -833,6 +867,11 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
                 makeDiff(((GraphTreeLabel*)i)->nodename(),m_Selected->nodename());
             }
         break;
+        case 303:
+            if (i && i->rtti()==GRAPHTREE_LABEL) {
+                makeCat((GraphTreeLabel*)i);
+            }
+        break;
         case 401:
             makeSelected(0);
         break;
@@ -847,6 +886,21 @@ void RevGraphView::contentsContextMenuEvent(QContextMenuEvent* e)
     }
 }
 
+void RevGraphView::makeCat(GraphTreeLabel*_l)
+{
+    if (!_l) {
+        return;
+    }
+    QString n1 = _l->nodename();
+    trevTree::ConstIterator it = m_Tree.find(n1);
+    if (it==m_Tree.end()) {
+        return;
+    }
+    svn::Revision tr(it.data().rev);
+    QString tp = _basePath+it.data().name;
+    emit makeCat(tr,tp,it.data().name,tr,kapp->activeModalWidget());
+}
+
 void RevGraphView::makeDiffPrev(GraphTreeLabel*_l)
 {
     if (!_l) return;
@@ -873,23 +927,11 @@ void RevGraphView::makeDiff(const QString&n1,const QString&n2)
     }
     svn::Revision tr(it.data().rev);
     QString tp = _basePath+it.data().name;
-    QString ex = "";
-    KTempDir tdir;
-    tdir.setAutoDelete(true);
-    kdDebug()<<"Non recourse diff"<<endl;
-    QString tn = QString("%1/%2").arg(tdir.name()).arg("/svndiff");
-    bool ignore_content = Settings::diff_ignore_content();
-    try {
-        StopDlg sdlg(m_Listener,kapp->activeModalWidget(),0,"Diffing","Diffing - hit cancel for abort");
-        ex = m_Client->diff(svn::Path(tn),
-            svn::Path(sp),svn::Path(tp),
-            sr, tr,
-            false,false,false,ignore_content);
-    } catch (svn::ClientException e) {
-//        emit clientException(e.msg());
-        return;
+    if (Kdesvnsettings::tree_diff_rec()) {
+        emit makeRecDiff(sp,sr,tp,tr,kapp->activeModalWidget());
+    } else {
+        emit makeNorecDiff(sp,sr,tp,tr,kapp->activeModalWidget());
     }
-    emit dispDiff(ex);
 }
 
 void RevGraphView::setBasePath(const QString&_path)
@@ -897,4 +939,9 @@ void RevGraphView::setBasePath(const QString&_path)
     _basePath = _path;
 }
 
+void RevGraphView::slotClientException(const QString&what)
+{
+    KMessageBox::sorry(KApplication::activeModalWidget(),what,i18n("SVN Error"));
+}
+
 #include "revgraphview.moc"
