@@ -19,7 +19,7 @@
  ***************************************************************************/
 #include "revisiontree.h"
 #include "../stopdlg.h"
-#include "svnqt/log_entry.hpp"
+#include "src/svnqt/log_entry.hpp"
 #include "helpers/sub2qt.h"
 #include "revtreewidget.h"
 #include "revgraphview.h"
@@ -30,6 +30,8 @@
 #include <klocale.h>
 #include <kapp.h>
 #include <klistview.h>
+#include <kmdcodec.h>
+#include <kmessagebox.h>
 
 #include <qwidget.h>
 #include <qdatetime.h>
@@ -59,9 +61,9 @@ public:
     RevTreeWidget*m_TreeDisplay;
 
     svn::Client*m_Client;
-    CContextListener* m_Listener;
+    QObject* m_Listener;
 
-    bool getLogs(const QString&);
+    bool getLogs(const QString&,const svn::Revision&startr,const svn::Revision&endr);
 };
 
 RtreeData::RtreeData()
@@ -79,25 +81,27 @@ RtreeData::~RtreeData()
     delete progress;
 }
 
-bool RtreeData::getLogs(const QString&reposRoot)
+bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const svn::Revision&endr)
 {
     if (!m_Listener||!m_Client) {
         return false;
     }
     try {
         StopDlg sdlg(m_Listener,dlgParent,
-            0,"Logs","Getting logs - hit cancel for abort");
-        m_Client->log(reposRoot,svn::Revision::HEAD,svn::Revision((long)0),m_OldHistory,true,false,0);
+                     0,"Logs",i18n("Getting logs - hit cancel for abort"));
+        m_Client->log(reposRoot,endr,startr,m_OldHistory,true,false,0);
     } catch (svn::ClientException ce) {
         kdDebug()<<ce.msg() << endl;
+        KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1").arg(ce.msg()));
         return false;
     }
     return true;
 }
 
 RevisionTree::RevisionTree(svn::Client*aClient,
-    CContextListener*aListener,
+    QObject*aListener,
     const QString& reposRoot,
+    const svn::Revision&startr,const svn::Revision&endr,
     const QString&origin,
     const svn::Revision& baserevision,
     QWidget*treeParent,QWidget*parent)
@@ -108,7 +112,7 @@ RevisionTree::RevisionTree(svn::Client*aClient,
     m_Data->m_Listener=aListener;
     m_Data->dlgParent=parent;
 
-    if (!m_Data->getLogs(reposRoot)) {
+    if (!m_Data->getLogs(reposRoot,startr,endr)) {
         return;
     }
 
@@ -187,7 +191,8 @@ RevisionTree::~RevisionTree()
 bool RevisionTree::isDeleted(long revision,const QString&path)
 {
     for (unsigned i = 0;i<m_Data->m_History[revision].changedPaths.count();++i) {
-        if (isParent(m_Data->m_History[revision].changedPaths[i].path,path) && m_Data->m_History[revision].changedPaths[i].action=='D') {
+        if (isParent(m_Data->m_History[revision].changedPaths[i].path,path) &&
+            m_Data->m_History[revision].changedPaths[i].action=='D') {
             return true;
         }
     }
@@ -213,7 +218,8 @@ bool RevisionTree::topDownScan()
                     cancel=true;
                     break;
                 }
-                label = QString("%1<br>Check change entry %2 of %3").arg(olabel).arg(i).arg(m_Data->m_OldHistory[j].changedPaths.count());
+                label = QString("%1<br>Check change entry %2 of %3")
+                        .arg(olabel).arg(i).arg(m_Data->m_OldHistory[j].changedPaths.count());
                 m_Data->progress->setLabel(label);
                 kapp->processEvents();
             }
@@ -278,7 +284,7 @@ bool RevisionTree::topDownScan()
                             break;
                         }
                     }
-                    m_Data->m_History[j].addCopyTo(sourcepath,m_Data->m_OldHistory[j].changedPaths[i].path,j,a,r);
+                    m_Data->m_History[r].addCopyTo(sourcepath,m_Data->m_OldHistory[j].changedPaths[i].path,j,a,r);
                     m_Data->m_OldHistory[j].changedPaths[i].action=0;
                 } else {
                     kdDebug()<<"Action with source path but wrong action \""<<a<<"\" found!"<<endl;
@@ -336,7 +342,7 @@ bool RevisionTree::isValid()const
 
 static QString uniqueNodeName(long rev,const QString&path)
 {
-    QString res = path;
+    QString res = KCodecs::base64Encode(path.local8Bit(),false);
     res.replace("\"","_quot_");
     res.replace(" ","_space_");
     QString n; n.sprintf("%05ld",rev);
@@ -351,6 +357,8 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
 
     QString path = _path;
     long lastrev = _last;
+    /* this is required if an item will modified AND copied at same revision.*/
+    long trev = -1;
 #ifdef DEBUG_PARSE
     kdDebug()<<"Searching for "<<path<< " at revision " << startrev
         << " recursion " << recurse << endl;
@@ -379,14 +387,8 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
 #endif
                 }
                 if (FORWARDENTRY.action==INTERNALCOPY ||
-                    /* FORWARDENTRY.action=='R' || */
                     FORWARDENTRY.action==INTERNALRENAME ) {
-#if 0
-                    if (FORWARDENTRY.action=='R' && FORWARDENTRY.path!=path ) {
-                        continue;
-                    }
-#endif
-                    bool ren = /* FORWARDENTRY.action=='R'|| */ FORWARDENTRY.action==INTERNALRENAME;
+                    bool ren = FORWARDENTRY.action==INTERNALRENAME;
                     QString tmpPath = path;
                     QString recPath;
                     if (FORWARDENTRY.copyToPath.length()==0) {
@@ -396,26 +398,29 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     recPath= FORWARDENTRY.copyToPath;
                     recPath+=r;
                     n1 = uniqueNodeName(lastrev,tmpPath);
-                    n2 = uniqueNodeName(j,recPath);
-                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n1].targets.append(RevGraphView::targetData(n2,FORWARDENTRY.action));
-                    fillItem(j,i,n2,recPath);
-                    if (ren) {
-                        lastrev = j;
+                    n2 = uniqueNodeName(FORWARDENTRY.copyToRevision,recPath);
+                    if (lastrev>0) {
+                        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n1].targets.append(RevGraphView::targetData(n2,FORWARDENTRY.action));
                     }
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].name=recPath;
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].rev = FORWARDENTRY.copyToRevision;
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].Action=FORWARDENTRY.action;
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].Author=m_Data->m_History[FORWARDENTRY.copyToRevision].author;
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].Message=m_Data->m_History[FORWARDENTRY.copyToRevision].message;
+                    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].Date=helpers::sub2qt::apr_time2qtString(m_Data->m_History[FORWARDENTRY.copyToRevision].date);
                     if (ren) {
+                        lastrev = FORWARDENTRY.copyToRevision;
+                        /* skip items between */
+                        j=lastrev;
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"Renamed to "<< recPath << " at revison " << j << endl;
+                        kdDebug()<<"Renamed to "<< recPath << " at revison " << FORWARDENTRY.copyToRevision << endl;
 #endif
                         path=recPath;
-                    }
+                    } else {
 #ifdef DEBUG_PARSE
-                     else {
-
                         kdDebug()<<"Copy to "<< recPath << endl;
-                    }
 #endif
-                    if (!ren) {
-                        if (!bottomUpScan(FORWARDENTRY.copyToRevision,recurse+1,recPath,j)) {
+                        if (!bottomUpScan(FORWARDENTRY.copyToRevision,recurse+1,recPath,FORWARDENTRY.copyToRevision)) {
                             return false;
                         }
                     }
@@ -436,8 +441,13 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
 #endif
                         n1 = uniqueNodeName(j,FORWARDENTRY.path);
                         n2 = uniqueNodeName(lastrev,FORWARDENTRY.path);
-                        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
+                        if (lastrev>0) m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
                         fillItem(j,i,n1,path);
+                        /* modify of same item (in same recurse) should be only once at a revision
+                         * so check if lastrev==j must not be done but will cost cpu ticks so I always
+                         * set trev and lastrev.
+                         */
+                        trev = lastrev;
                         lastrev = j;
                     break;
                     case 'D':
@@ -452,10 +462,10 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                              */
                             n1 = uniqueNodeName(j,"D_"+path);
                         }
-                        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
+                        if (lastrev>0) m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
                         fillItem(j,i,n1,path);
                         lastrev = j;
-                        //get_out= true;
+                        get_out= true;
                     break;
                     default:
                     break;
@@ -474,10 +484,10 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                              */
                             n1 = uniqueNodeName(j,"D_"+path);
                         }
-                        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
+                        if (lastrev>0) m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n2].targets.append(RevGraphView::targetData(n1,FORWARDENTRY.action));
                         fillItem(j,i,n1,path);
                         lastrev = j;
-                        //get_out = true;
+                        get_out = true;
                     break;
                     default:
                     break;
@@ -499,10 +509,17 @@ QWidget*RevisionTree::getView()
 
 void RevisionTree::fillItem(long rev,int pathIndex,const QString&nodeName,const QString&path)
 {
-    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Action=m_Data->m_History[rev].changedPaths[pathIndex].action;
     m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].name=path;
     m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].rev = rev;
-    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Author=m_Data->m_History[rev].author;
-    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Message=m_Data->m_History[rev].message;
-    m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Date=helpers::sub2qt::apr_time2qtString(m_Data->m_History[rev].date);
+    if (pathIndex>=0) {
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Action=m_Data->m_History[rev].changedPaths[pathIndex].action;
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Author=m_Data->m_History[rev].author;
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Message=m_Data->m_History[rev].message;
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Date=helpers::sub2qt::apr_time2qtString(m_Data->m_History[rev].date);
+    } else {
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Action=0;
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Author="";
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Message="";
+        m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[nodeName].Date=helpers::sub2qt::apr_time2qtString(0);
+    }
 }
