@@ -27,13 +27,14 @@
 #include "svnactions.h"
 #include "svnfiletip.h"
 #include "keystatus.h"
+#include "opencontextmenu.h"
 #include "checkoutinfo_impl.h"
-#include "fronthelpers/settings.h"
-#include "svnqt/revision.hpp"
-#include "svnqt/dirent.hpp"
-#include "svnqt/client.hpp"
-#include "svnqt/status.hpp"
-#include "svnqt/url.hpp"
+#include "src/settings/kdesvnsettings.h"
+#include "src/svnqt/revision.hpp"
+#include "src/svnqt/dirent.hpp"
+#include "src/svnqt/client.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/url.hpp"
 #include "helpers/sshagent.h"
 #include "helpers/sub2qt.h"
 
@@ -55,6 +56,7 @@
 #include <kio/job.h>
 #include <krun.h>
 #include <kurldrag.h>
+#include <ktrader.h>
 
 #include <qvbox.h>
 #include <qpainter.h>
@@ -126,9 +128,9 @@ KdesvnFileListPrivate::KdesvnFileListPrivate()
 
 void KdesvnFileListPrivate::readSettings()
 {
-    mlist_icon_size = Settings::listview_icon_size();
-    mdisp_ignored_files = Settings::display_ignored_files();
-    mdisp_overlay = Settings::display_overlays();
+    mlist_icon_size = Kdesvnsettings::listview_icon_size();
+    mdisp_ignored_files = Kdesvnsettings::display_ignored_files();
+    mdisp_overlay = Kdesvnsettings::display_overlays();
 }
 
 bool KdesvnFileListPrivate::reReadSettings()
@@ -147,7 +149,7 @@ kdesvnfilelist::kdesvnfilelist(KActionCollection*aCollect,QWidget *parent, const
     m_pList = new KdesvnFileListPrivate;
     m_filesAction = aCollect;
     m_pList->m_fileTip=new SvnFileTip(this);
-    m_pList->m_fileTip->setOptions(Settings::display_file_tips()&&
+    m_pList->m_fileTip->setOptions(Kdesvnsettings::display_file_tips()&&
         QToolTip::isGloballyEnabled(),true,6);
 
     SshAgent ssh;
@@ -167,7 +169,6 @@ kdesvnfilelist::kdesvnfilelist(KActionCollection*aCollect,QWidget *parent, const
     setSortColumn(FileListViewItem::COL_NAME);
     setupActions();
 
-    connect(this,SIGNAL(clicked(QListViewItem*)),this,SLOT(slotItemClicked(QListViewItem*)));
     connect(this,SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)),this,
         SLOT(slotContextMenuRequested(QListViewItem *, const QPoint &, int)));
 
@@ -208,6 +209,8 @@ void kdesvnfilelist::setupActions()
     m_LogRangeAction = new KAction(i18n("Log..."),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_L),this,SLOT(slotMakeRangeLog()),m_filesAction,"make_svn_log");
     m_LogFullAction = new KAction(i18n("Full Log"),"kdesvnlog",KShortcut(CTRL+Key_L),this,SLOT(slotMakeLog()),m_filesAction,"make_svn_log_full");
     tmp_action = new KAction(i18n("Full revision tree"),"kdesvnlog",KShortcut(CTRL+Key_T),this,SLOT(slotMakeTree()),m_filesAction,"make_svn_tree");
+    tmp_action = new KAction(i18n("Partial revision tree"),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_T),
+        this,SLOT(slotMakePartTree()),m_filesAction,"make_svn_partialtree");
 
     m_propertyAction = new KAction(i18n("Properties"),"edit",
         KShortcut(Key_P),m_SvnWrapper,SLOT(slotProperties()),m_filesAction,"make_svn_property");
@@ -258,6 +261,7 @@ void kdesvnfilelist::setupActions()
 
     m_CleanupAction = new KAction(i18n("Cleanup"),"kdesvncleanup",
 	KShortcut(),this,SLOT(slotCleanupAction()),m_filesAction,"make_cleanup");
+    m_CleanupAction->setToolTip(i18n("Recursively clean up the working copy, removing locks, resuming unfinished operations, etc."));
     m_ImportDirsIntoCurrent  = new KAction(i18n("Import folders into current"),"fileimport",KShortcut(),
         this,SLOT(slotImportDirsIntoCurrent()),m_filesAction,"make_import_dirs_into_current");
     m_ImportDirsIntoCurrent->setToolTip(i18n("Import folder content into current url"));
@@ -299,11 +303,12 @@ void kdesvnfilelist::setupActions()
 
     m_MergeRevisionAction = new KAction(i18n("Merge two revisions"),"kdesvnmerge",
         KShortcut(),this,SLOT(slotMergeRevisions()),m_filesAction,"make_svn_merge_revisions");
-    m_MergeRevisionAction->setToolTip(i18n("Merge two revisions of these entry into itself"));
+    m_MergeRevisionAction->setToolTip(i18n("Merge two revisions of this entry into itself"));
 
     tmp_action=new KAction(i18n("Merge..."),"kdesvnmerge",
         KShortcut(),this,SLOT(slotMerge()),m_filesAction,"make_svn_merge");
     tmp_action->setToolTip("Merge repository path into current worky copy path or current repository path into a target");
+    tmp_action=new KAction( i18n( "Open With..." ), 0, this, SLOT( slotOpenWith() ), m_filesAction, "openwith" );
 
     /* remote actions only */
     m_CheckoutCurrentAction = new KAction(i18n("Checkout current repository path"),"kdesvncheckout",KShortcut(),
@@ -463,7 +468,8 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
         }
     }
 
-    if (url.protocol()=="svn+ssh") {
+    if (url.protocol()=="svn+ssh"||
+        url.protocol()=="ksvn+ssh") {
         SshAgent ssh;
         ssh.addSshIdentities();
     }
@@ -490,12 +496,12 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
         clear();
     }
     enableActions();
-    m_pList->m_fileTip->setOptions(!isNetworked()&&Settings::display_file_tips()&&
+    m_pList->m_fileTip->setOptions(!isNetworked()&&Kdesvnsettings::display_file_tips()&&
         QToolTip::isGloballyEnabled(),true,6);
 
-    if (isWorkingCopy()) {
+    if (result && isWorkingCopy()) {
         m_SvnWrapper->createModifiedCache(baseUri());
-        if (Settings::start_updates_check_on_open()) {
+        if (Kdesvnsettings::start_updates_check_on_open()) {
              slotCheckUpdates();
         }
     }
@@ -605,8 +611,8 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
             item->setDropEnabled(true);
             if (isWorkingCopy()) {
                 m_pList->m_DirWatch->addDir(item->fullName());
+                kdDebug()<< "Watching folder: " + item->fullName() << endl;
             }
-            kdDebug()<< "Watching folder: " + item->fullName() << endl;
         } else if (isWorkingCopy()) {
             m_pList->m_DirWatch->addFile(item->fullName());
 #if 0
@@ -619,7 +625,7 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
     }
 #if 0
     if (oneItem.count()>0) {
-        int size = Settings::listview_icon_size();
+        int size = Kdesvnsettings::listview_icon_size();
         KIO::PreviewJob* m_previewJob= KIO::filePreview(oneItem, size, size, size, 70, true, true, 0);
         connect( m_previewJob, SIGNAL( gotPreview( const KFileItem *, const QPixmap & ) ),
                  this, SLOT( gotPreview( const KFileItem *, const QPixmap & ) ) );
@@ -695,7 +701,7 @@ kdesvnfilelist::~kdesvnfilelist()
     ssh.killSshAgent();
 }
 
-void kdesvnfilelist::slotItemClicked(QListViewItem*aItem)
+void kdesvnfilelist::slotItemRead(QListViewItem*aItem)
 {
     if (!aItem) return;
     FileListViewItem* k = static_cast<FileListViewItem*>( aItem );
@@ -732,7 +738,6 @@ void kdesvnfilelist::slotReinitItem(SvnItem*item)
         k->removeChilds();
         m_Dirsread[k->fullName()]=false;;
     }
-    slotItemClicked(k);
 }
 
 void kdesvnfilelist::enableActions()
@@ -754,6 +759,10 @@ void kdesvnfilelist::enableActions()
     if (temp) {
         temp->setEnabled(single||none);
     }
+    temp = filesActions()->action("make_svn_partialtree");
+    if (temp) {
+        temp->setEnabled(single||none);
+    }
 
     m_propertyAction->setEnabled(single);
     m_DelCurrent->setEnabled( (multi||single));
@@ -788,7 +797,7 @@ void kdesvnfilelist::enableActions()
     m_MergeRevisionAction->setEnabled(single&&isWorkingCopy());
     temp = filesActions()->action("make_svn_merge");
     if (temp) {
-        temp->setEnabled(single);
+        temp->setEnabled(single||none);
     }
     temp = filesActions()->action("make_svn_addrec");
     if (temp) {
@@ -800,11 +809,15 @@ void kdesvnfilelist::enableActions()
     m_simpleDiffHead->setEnabled(isWorkingCopy()&&isopen);
     temp = filesActions()->action("make_svn_basediff");
     if (temp) {
-        temp->setEnabled(isWorkingCopy()&&isopen);
+        temp->setEnabled(isWorkingCopy()&&isopen&&single);
+    }
+    temp = filesActions()->action("make_svn_headdiff");
+    if (temp) {
+        temp->setEnabled(isWorkingCopy()&&isopen&&single);
     }
 
     /* 2. on dirs only */
-    m_CleanupAction->setEnabled(isWorkingCopy()&&dir);
+    m_CleanupAction->setEnabled(isWorkingCopy()&& (dir||none));
     temp = filesActions()->action("make_check_unversioned");
     if (temp) {
         temp->setEnabled(isWorkingCopy()&& ((dir&&single) || none));
@@ -819,7 +832,7 @@ void kdesvnfilelist::enableActions()
 
     temp = filesActions()->action("make_revisions_diff");
     if (temp) {
-        temp->setEnabled(isopen);
+        temp->setEnabled(isopen&&single);
     }
     temp = filesActions()->action("make_revisions_cat");
     if (temp) {
@@ -833,6 +846,10 @@ void kdesvnfilelist::enableActions()
     if (temp) {
         temp->setEnabled(isWorkingCopy()&&isopen);
     }
+    temp = filesActions()->action("openwith");
+    if (temp) {
+        temp->setEnabled(kapp->authorizeKAction("openwith")&&single&&!dir);
+    }
 }
 
 void kdesvnfilelist::slotSelectionChanged()
@@ -896,17 +913,22 @@ void kdesvnfilelist::slotItemDoubleClicked(QListViewItem*item)
         return;
     }
     svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:m_pList->m_remoteRevision);
-    QString what = fki->kdeName(rev).prettyURL();
-    QString feditor = Settings::external_display();
-    if ( feditor.compare("default") == 0 )
-    {
-        KFileItem fitem(KFileItem::Unknown,KFileItem::Unknown,what);
-        fitem.run();
-    }
-    else
-    {
-        if ( KRun::runCommand(feditor + " " +  what) <= 0)
-        {
+    QString feditor = Kdesvnsettings::external_display();
+    if ( feditor.compare("default") == 0 ) {
+        KURL::List lst;
+        lst.append(fki->kdeName(rev));
+        KTrader::OfferList li = offersList(fki,true);
+        if (li.count()==0||li.first()->exec().isEmpty()) {
+            li = offersList(fki);
+        }
+        if (li.count()>0&&!li.first()->exec().isEmpty()) {
+            KService::Ptr ptr = li.first();
+            KRun::run( *ptr, lst);
+        } else {
+            KRun::displayOpenWithDialog(lst);
+        }
+    } else {
+        if ( KRun::runCommand(feditor + " " +  fki->kdeName(rev).prettyURL()) <= 0) {
             KMessageBox::error(this,i18n("Failed: %1 %2").arg(feditor).arg(fki->fullName()));
         }
     }
@@ -918,8 +940,9 @@ void kdesvnfilelist::slotCleanupAction()
     FileListViewItem*which= singleSelected();
     if (!which) which = static_cast<FileListViewItem*>(firstChild());
     if (!which||!which->isDir()) return;
-    m_SvnWrapper->slotCleanup(which->fullName());
-    which->refreshStatus(true);
+    if (m_SvnWrapper->makeCleanup(which->fullName())) {
+        which->refreshStatus(true);
+    }
 }
 
 void kdesvnfilelist::slotResolved()
@@ -933,19 +956,26 @@ void kdesvnfilelist::slotResolved()
     slotRescanIcons(false);
 }
 
-template<class T> KDialogBase* kdesvnfilelist::createDialog(T**ptr,const QString&_head,bool OkCancel,const char*name)
+template<class T> KDialogBase* kdesvnfilelist::createDialog(T**ptr,const QString&_head,bool OkCancel,const char*name,bool showHelp)
 {
+    int buttons = KDialogBase::Ok;
+    if (OkCancel) {
+        buttons = buttons|KDialogBase::Cancel;
+    }
+    if (showHelp) {
+        buttons = buttons|KDialogBase::Help;
+    }
     KDialogBase * dlg = new KDialogBase(
         KApplication::activeModalWidget(),
         name,
         true,
         _head,
-        (OkCancel?KDialogBase::Ok|KDialogBase::Cancel:KDialogBase::Ok));
+        buttons);
 
     if (!dlg) return dlg;
     QWidget* Dialog1Layout = dlg->makeVBoxMainWidget();
     *ptr = new T(Dialog1Layout);
-    dlg->resize(dlg->configDialogSize(*(Settings::self()->config()),name?name:"standard_size"));
+    dlg->resize(dlg->configDialogSize(*(Kdesvnsettings::self()->config()),name?name:"standard_size"));
     return dlg;
 }
 
@@ -1010,7 +1040,7 @@ void kdesvnfilelist::slotImportIntoDir(const KURL&importUrl,const QString&target
         delete dlg;
         return;
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"import_log_msg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"import_log_msg",false);
 
     QString logMessage = ptr->getMessage();
     bool rec = ptr->isRecursive();
@@ -1030,7 +1060,7 @@ void kdesvnfilelist::slotImportIntoDir(const KURL&importUrl,const QString&target
         if (allSelected()->count()==0) {
             refreshCurrentTree();
         } else {
-            slotReinitItem(allSelected()->at(0));
+            refreshCurrent(allSelected()->at(0));
         }
     }
     delete dlg;
@@ -1038,6 +1068,8 @@ void kdesvnfilelist::slotImportIntoDir(const KURL&importUrl,const QString&target
 
 void kdesvnfilelist::refreshCurrentTree()
 {
+    QTime t;
+    t.start();
     FileListViewItem*item = static_cast<FileListViewItem*>(firstChild());
     if (!item) return;
     m_pList->stopScan();
@@ -1057,11 +1089,8 @@ void kdesvnfilelist::refreshCurrentTree()
     }
     if (isWorkingCopy()) {
         m_SvnWrapper->createModifiedCache(baseUri());
-        if (Settings::start_updates_check_on_open()) {
-             slotRescanIcons(true);
-        }
     }
-
+    kdDebug()<<"Refresh time: "<<t.elapsed()<<" ms"<<endl;
     setUpdatesEnabled(true);
     viewport()->repaint();
     m_pList->startScan();
@@ -1107,6 +1136,11 @@ void kdesvnfilelist::refreshRecursive(FileListViewItem*_parent,bool down)
         kdDebug()<<"Fehler bei makestatus fuer "<<what <<endl;
         return;
     }
+    if (isWorkingCopy()) {
+        svn::StatusEntries neweritems;
+        m_SvnWrapper->getaddedItems(what,neweritems);
+        dlist+=neweritems;
+    }
 
     svn::StatusEntries::iterator it = dlist.begin();
     FileListViewItem*k;
@@ -1187,27 +1221,96 @@ void kdesvnfilelist::refreshRecursive(FileListViewItem*_parent,bool down)
     }
 }
 
-void kdesvnfilelist::slotContextMenuRequested(QListViewItem *_item, const QPoint &, int)
+KTrader::OfferList kdesvnfilelist::offersList(SvnItem*item,bool execOnly)
 {
-    FileListViewItem*item = static_cast<FileListViewItem*>(_item);
-    bool isopen = baseUri().length()>0;
-    if (item) {
-        if (isWorkingCopy()) {
-            emit sigShowPopup("local_context");
-        } else {
-            emit sigShowPopup("remote_context");
-        }
+    KTrader::OfferList offers;
+    if (!item) {
+        return offers;
+    }
+    QString constraint;
+    if (execOnly) {
+        constraint = "Type == 'Application' or (exist Exec)";
     } else {
-        if (!isopen) {
-            emit sigShowPopup("general_empty");
-        } else {
-            if (isWorkingCopy()) {
-                emit sigShowPopup("general_local");
+        constraint = "Type == 'Application'";
+    }
+    offers = KTrader::self()->query(item->mimeType()->name(), constraint);
+
+    return offers;
+}
+
+void kdesvnfilelist::slotContextMenuRequested(QListViewItem */* _item */, const QPoint &, int)
+{
+//    FileListViewItem*item = static_cast<FileListViewItem*>(_item);
+    bool isopen = baseUri().length()>0;
+    SvnItemList l;
+    SelectionList(&l);
+
+    QString menuname;
+
+    if (!isopen) {
+        menuname="empty";
+    } else if (isWorkingCopy()) {
+        menuname="local";
+    } else {
+        menuname="remote";
+    }
+    if (l.count()==0) {
+        menuname+="_general";
+    } else if (l.count()>1){
+        menuname+="_context_multi";
+    } else {
+        menuname+="_context_single";
+        if (isWorkingCopy()) {
+            if (l.at(0)->isRealVersioned()) {
+                menuname+="_versioned";
+                if (l.at(0)->isDir()) {
+                    menuname+="_dir";
+                }
             } else {
-                emit sigShowPopup("general_remote");
+                menuname+="_unversioned";
+            }
+        } else if (l.at(0)->isDir()) {
+            menuname+="_dir";
+        }
+    }
+
+    QWidget * target;
+    emit sigShowPopup(menuname,&target);
+    QPopupMenu *popup = static_cast<QPopupMenu *>(target);
+    if (!popup) {
+        kdDebug()<<"Error getting popupMenu"<<endl;
+        return;
+    }
+
+    KTrader::OfferList offers;
+    OpenContextmenu*me=0;
+    KAction*temp = 0;
+
+    int id = -1;
+
+    if (l.count()==1) offers = offersList(l.at(0));
+
+    if (l.count()==1&&!l.at(0)->isDir()) {
+        temp = filesActions()->action("openwith");
+        if (offers.count()>0) {
+            svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:m_pList->m_remoteRevision);
+            me= new OpenContextmenu(l.at(0)->kdeName(rev),offers,0,0);
+            id = popup->insertItem(i18n("Open With..."),me);
+        } else {
+            temp = filesActions()->action("openwith");
+            if (temp) {
+                temp->plug(popup);
             }
         }
     }
+    popup->exec(QCursor::pos());
+    if (id>-1) {
+        popup->removeItem(id);
+    }
+    delete me;
+    if (temp) {
+        temp->unplug(popup);
+    }
 }
 
 /**
@@ -1228,12 +1331,18 @@ void kdesvnfilelist::startDrag()
 {
     m_pList->m_fileTip->setItem(0);
     QListViewItem * m_pressedItem = currentItem();
+    if (!m_pressedItem) {
+        return;
+    }
     QPixmap pixmap2;
     KURL::List urls = selectedUrls();
+    if (urls.count()==0) {
+        return;
+    }
     kdDebug() << urls << endl;
     bool pixmap0Invalid = !m_pressedItem->pixmap(0) || m_pressedItem->pixmap(0)->isNull();
     if (( urls.count() > 1 ) || (pixmap0Invalid)) {
-      int iconSize = Settings::listview_icon_size();;
+      int iconSize = Kdesvnsettings::listview_icon_size();;
       iconSize = iconSize ? iconSize : kdesvnPartFactory::instance()->iconLoader()->currentSize( KIcon::Small ); // Default = small
       pixmap2 = DesktopIcon( "kmultiple", iconSize );
       if ( pixmap2.isNull() ) {
@@ -1372,12 +1481,16 @@ void kdesvnfilelist::slotMergeRevisions()
     if (!which) {
         return;
     }
-    bool force,dry,rec,irelated;
+    bool force,dry,rec,irelated,useExternal;
     Rangeinput_impl::revision_range range;
-    if (!MergeDlg_impl::getMergeRange(range,&force,&rec,&irelated,&dry,this,"merge_range")) {
+    if (!MergeDlg_impl::getMergeRange(range,&force,&rec,&irelated,&dry,&useExternal,this,"merge_range")) {
         return;
     }
-    m_SvnWrapper->slotMergeWcRevisions(which->fullName(),range.first,range.second,rec,irelated,force,dry);
+    if (!useExternal) {
+        m_SvnWrapper->slotMergeWcRevisions(which->fullName(),range.first,range.second,rec,irelated,force,dry);
+    } else {
+        m_SvnWrapper->slotMergeExternal(which->fullName(),which->fullName(),which->fullName(),range.first,range.second,rec);
+    }
     refreshItem(which);
     refreshRecursive(which);
 }
@@ -1386,21 +1499,19 @@ void kdesvnfilelist::slotMerge()
 {
     FileListViewItem*which= singleSelected();
     QString src1,src2,target;
-    if (which) {
-        if (isWorkingCopy()) {
-            target = which->fullName();
-        } else {
-            src1 = which->fullName();
-        }
+    if (isWorkingCopy()) {
+        target = which?which->fullName():baseUri();
+    } else {
+        src1 = which?which->fullName():baseUri();
     }
-    bool force,dry,rec,irelated;
+    bool force,dry,rec,irelated,useExternal;
     Rangeinput_impl::revision_range range;
     MergeDlg_impl*ptr;
-    KDialogBase*dlg = createDialog(&ptr,QString(i18n("Merge")),true,"merge_dialog");
+    KDialogBase*dlg = createDialog(&ptr,QString(i18n("Merge")),true,"merge_dialog",true);
     if (!dlg) {
         return;
     }
-
+    dlg->setHelp("merging-items","kdesvn");
     ptr->setDest(target);
     ptr->setSrc1(src1);
     ptr->setSrc2(src1);
@@ -1415,8 +1526,13 @@ void kdesvnfilelist::slotMerge()
         dry = ptr->dryrun();
         rec = ptr->recursive();
         irelated = ptr->ignorerelated();
+        useExternal = ptr->useExtern();
         range = ptr->getRange();
-        m_SvnWrapper->slotMerge(src1,src2,target,range.first,range.second,rec,irelated,force,dry);
+        if (!useExternal) {
+            m_SvnWrapper->slotMerge(src1,src2,target,range.first,range.second,rec,irelated,force,dry);
+        } else {
+            m_SvnWrapper->slotMergeExternal(src1,src2,target,range.first,range.second,rec);
+        }
         if (isWorkingCopy()) {
 //            refreshItem(which);
 //            refreshRecursive(which);
@@ -1424,7 +1540,7 @@ void kdesvnfilelist::slotMerge()
         }
     }
 
-    dlg->saveDialogSize(*(Settings::self()->config()),"merge_dialog",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"merge_dialog",false);
 
     delete dlg;
 }
@@ -1577,8 +1693,8 @@ void kdesvnfilelist::slotCat()
 {
     FileListViewItem*k = singleSelected();
     if (!k) return;
-    m_SvnWrapper->makeCat(isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision, k->fullName(),k->text(0),
-        isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision);
+    m_SvnWrapper->slotMakeCat(isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision, k->fullName(),k->text(0),
+        isWorkingCopy()?svn::Revision::HEAD:m_pList->m_remoteRevision,0);
 }
 
 
@@ -1717,7 +1833,7 @@ void kdesvnfilelist::slotLock()
         delete dlg;
         return;
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"locking_log_msg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"locking_log_msg",false);
 
     QString logMessage = ptr->getMessage();
     bool rec = ptr->isRecursive();
@@ -1803,46 +1919,37 @@ void kdesvnfilelist::slotRangeBlame()
         Rangeinput_impl::revision_range r = rdlg->getRange();
         m_SvnWrapper->makeBlame(r.first,r.second,k);
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"revisions_dlg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
     delete dlg;
 }
 
 
 void kdesvnfilelist::slotSimpleBaseDiff()
 {
-    FileListViewItemList*klist = allSelected();
-    QStringList what;
+    FileListViewItem*kitem = singleSelected();
 
-    if (!klist||klist->count()==0) {
-        what<<baseUri();
-    }else{
-        FileListViewItemListIterator liter(*klist);
-        FileListViewItem*cur;
-        while ((cur=liter.current())!=0){
-            ++liter;
-            what<<cur->fullName();
-        }
+    QString what;
+    if (!kitem) {
+        what==baseUri();
+    } else {
+        what = kitem->fullName();
     }
-
-    m_SvnWrapper->makeDiff(what,svn::Revision::UNDEFINED,svn::Revision::UNDEFINED);
+    // only possible on working copies - so we may say this values
+    m_SvnWrapper->makeDiff(what,svn::Revision::BASE,svn::Revision::WORKING,kitem?kitem->isDir():true);
 }
 
 void kdesvnfilelist::slotSimpleHeadDiff()
 {
-    FileListViewItemList*klist = allSelected();
-    QStringList what;
+    FileListViewItem*kitem = singleSelected();
+    QString what;
 
-    if (!klist||klist->count()==0) {
-        what<<baseUri();
+    if (!kitem) {
+        what=baseUri();
     }else{
-        FileListViewItemListIterator liter(*klist);
-        FileListViewItem*cur;
-        while ((cur=liter.current())!=0){
-            ++liter;
-            what<<cur->fullName();
-        }
+        what = kitem->fullName();
     }
-    m_SvnWrapper->makeDiff(what,svn::Revision::WORKING,svn::Revision::HEAD);
+    // only possible on working copies - so we may say this values
+    m_SvnWrapper->makeDiff(what,svn::Revision::WORKING,svn::Revision::HEAD,kitem?kitem->isDir():true);
 }
 
 
@@ -1868,6 +1975,25 @@ void kdesvnfilelist::slotMkdir()
     }
 }
 
+void kdesvnfilelist::slotMkBaseDirs()
+{
+    bool isopen = baseUri().length()>0;
+    if (!isopen) {
+        return;
+    }
+    QString parentDir=baseUri();
+    QStringList targets;
+    targets.append(parentDir+"/trunk");
+    targets.append(parentDir+"/branches");
+    targets.append(parentDir+"/tags");
+    QString msg = i18n("Automatic generated base layout by kdesvn");
+    isopen = m_SvnWrapper->makeMkdir(targets,msg);
+    if (isopen) {
+        slotDirAdded(targets[0],0);
+//        slotDirAdded(targets[1],0);
+//        slotDirAdded(targets[2],0);
+    }
+}
 
 /*!
     \fn kdesvnfilelist::slotDiffRevisions()
@@ -1888,9 +2014,9 @@ void kdesvnfilelist::slotDiffRevisions()
     }
     if (dlg->exec()==QDialog::Accepted) {
         Rangeinput_impl::revision_range r = rdlg->getRange();
-        m_SvnWrapper->makeDiff(what,r.first,r.second);
+        m_SvnWrapper->makeDiff(what,r.first,r.second,k?k->isDir():true);
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"revisions_dlg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
     delete dlg;
 
 }
@@ -1913,7 +2039,7 @@ void kdesvnfilelist::slotSelectBrowsingRevision()
             refreshCurrentTree();
         }
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"revisions_dlg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
     delete dlg;
 }
 
@@ -1932,9 +2058,9 @@ void kdesvnfilelist::slotRevisionCat()
     rdlg->setStartOnly(true);
     if (dlg->exec()==QDialog::Accepted) {
         Rangeinput_impl::revision_range r = rdlg->getRange();
-        m_SvnWrapper->makeCat(r.first, k->fullName(),k->shortName());
+        m_SvnWrapper->slotMakeCat(r.first, k->fullName(),k->shortName(),r.first,0);
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"revisions_dlg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
     delete dlg;
 }
 
@@ -2001,13 +2127,13 @@ void kdesvnfilelist::slotInfo()
     }
     if (lst.count()==0) {
         if (!isWorkingCopy()) {
-            m_SvnWrapper->makeInfo(baseUri(),rev,svn::Revision::UNDEFINED,Settings::info_recursive());
+            m_SvnWrapper->makeInfo(baseUri(),rev,svn::Revision::UNDEFINED,Kdesvnsettings::info_recursive());
         } else {
             lst.append(SelectedOrMain());
         }
     }
     if (lst.count()>0) {
-        m_SvnWrapper->makeInfo(lst,rev,svn::Revision::UNDEFINED,Settings::info_recursive());
+        m_SvnWrapper->makeInfo(lst,rev,svn::Revision::UNDEFINED,Kdesvnsettings::info_recursive());
     }
 }
 
@@ -2144,7 +2270,7 @@ FileListViewItem* kdesvnfilelist::findEntryItem(const QString&what,FileListViewI
  */
 void kdesvnfilelist::contentsMouseMoveEvent( QMouseEvent *e )
 {
-    if (Settings::display_file_tips()) {
+    if (Kdesvnsettings::display_file_tips()) {
 
         QPoint vp = contentsToViewport( e->pos() );
         FileListViewItem*item = isExecuteArea( vp ) ? static_cast<FileListViewItem*>(itemAt( vp )) : 0L;
@@ -2154,7 +2280,7 @@ void kdesvnfilelist::contentsMouseMoveEvent( QMouseEvent *e )
             QRect rect( viewportToContents( vp ), QSize(20, item->height()) );
             m_pList->m_fileTip->setItem( static_cast<SvnItem*>(item), rect, item->pixmap(0));
             m_pList->m_fileTip->setPreview(KGlobalSettings::showFilePreview(item->fullName())/*&&isWorkingCopy()*/
-                &&Settings::display_previews_in_file_tips());
+                &&Kdesvnsettings::display_previews_in_file_tips());
             setShowToolTips(false);
         } else {
             m_pList->m_fileTip->setItem(0);
@@ -2186,13 +2312,14 @@ void kdesvnfilelist::leaveEvent(QEvent*e)
 
 void kdesvnfilelist::slotSettingsChanged()
 {
-    m_pList->m_fileTip->setOptions(!isNetworked()&&Settings::display_file_tips()&&
+    m_pList->m_fileTip->setOptions(!isNetworked()&&Kdesvnsettings::display_file_tips()&&
         QToolTip::isGloballyEnabled(),true,6);
     if (m_pList->reReadSettings()) {
         refreshCurrentTree();
     } else {
         viewport()->repaint();
     }
+    sort();
 }
 
 
@@ -2223,7 +2350,7 @@ void kdesvnfilelist::slotRelocate()
         if (dlg->exec()==QDialog::Accepted) {
             done = m_SvnWrapper->makeRelocate(fromUrl,ptr->reposURL(),path,ptr->forceIt());
         }
-        dlg->saveDialogSize(*(Settings::self()->config()),"relocate_dlg",false);
+        dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"relocate_dlg",false);
         delete dlg;
         if (!done) return;
     }
@@ -2298,7 +2425,7 @@ void kdesvnfilelist::checkUnversionedDirs( FileListViewItem * _parent )
     //this->insertDirs(_parent, nonversioned_list);
 }
 
-void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer)
+void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer,bool no_update)
 {
     FileListViewItem*_s;
     if (!startAt) {
@@ -2312,15 +2439,16 @@ void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer)
     svn::Status d;
     while (_s) {
         //_s->makePixmap();
-        if (m_SvnWrapper->getUpdated(_s->stat().path(),d)) {
-            _s->updateStatus(d);
-        } else {
-            _s->update();
+        if (!no_update) {
+            if (m_SvnWrapper->getUpdated(_s->stat().path(),d)) {
+                _s->updateStatus(d);
+            } else {
+                _s->update();
+            }
         }
-        rescanIconsRec(_s,checkNewer);
+        rescanIconsRec(_s,checkNewer,no_update);
         if (checkNewer && _s->isDir() && _s->isOpen()) {
             svn::StatusEntries target;
-            kdDebug( ) << "Checking added items for " << _s->stat().path()<< " Revision: " << _s->stat().entry().revision() << endl;
             m_SvnWrapper->getaddedItems(_s->stat().path(),target);
             insertDirs(_s,target);
         }
@@ -2374,13 +2502,13 @@ void kdesvnfilelist::slotMakeRangeLog()
     if (!dlg) {
         return;
     }
-    bool list = Settings::self()->log_always_list_changed_files();
+    bool list = Kdesvnsettings::self()->log_always_list_changed_files();
     int i = dlg->exec();
     if (i==QDialog::Accepted) {
         Rangeinput_impl::revision_range r = rdlg->getRange();
         m_SvnWrapper->makeLog(r.first,r.second,what,list,0);
     }
-    dlg->saveDialogSize(*(Settings::self()->config()),"revisions_dlg",false);
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
 }
 
 
@@ -2400,6 +2528,35 @@ void kdesvnfilelist::slotMakeTree()
     m_SvnWrapper->makeTree(what,rev);
 }
 
+void kdesvnfilelist::slotMakePartTree()
+{
+    QString what;
+    SvnItem*k = SelectedOrMain();
+    if (k) {
+        what = k->fullName();
+    } else if (!isWorkingCopy() && allSelected()->count()==0){
+        what = baseUri();
+    } else {
+        return;
+    }
+    Rangeinput_impl*rdlg;
+    KDialogBase*dlg = createDialog(&rdlg,QString(i18n("Revisions")),true,"revisions_dlg");
+    if (!dlg) {
+        return;
+    }
+    int i = dlg->exec();
+    Rangeinput_impl::revision_range r;
+    if (i==QDialog::Accepted) {
+        r = rdlg->getRange();
+    }
+    dlg->saveDialogSize(*(Kdesvnsettings::self()->config()),"revisions_dlg",false);
+
+    if (i==QDialog::Accepted) {
+        svn::Revision rev(isWorkingCopy()?svn::Revision::WORKING:m_pList->m_remoteRevision);
+        m_SvnWrapper->makeTree(what,rev,r.first,r.second);
+    }
+}
+
 /*!
     \fn kdesvnfilelist::slotMakeLog()
  */
@@ -2421,8 +2578,8 @@ void kdesvnfilelist::slotMakeLog()
         start=m_pList->m_remoteRevision;
     }
     svn::Revision end(svn::Revision::START);
-    bool list = Settings::self()->log_always_list_changed_files();
-    int l = Settings::self()->maximum_displayed_logs();
+    bool list = Kdesvnsettings::self()->log_always_list_changed_files();
+    int l = Kdesvnsettings::self()->maximum_displayed_logs();
     m_SvnWrapper->makeLog(start,end,what,list,l);
 }
 
@@ -2431,4 +2588,20 @@ const svn::Revision& kdesvnfilelist::remoteRevision()const
     return m_pList->m_remoteRevision;
 }
 
+
+/*!
+    \fn kdesvnfilelist::slotOpenWith()
+ */
+void kdesvnfilelist::slotOpenWith()
+{
+    FileListViewItem* which = singleSelected();
+    if (!which||which->isDir()) {
+        return;
+    }
+    svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:m_pList->m_remoteRevision);
+    KURL::List lst;
+    lst.append(which->kdeName(rev));
+    KRun::displayOpenWithDialog(lst);
+}
+
 #include "kdesvnfilelist.moc"
