@@ -22,11 +22,12 @@
 
 #include "itemdisplay.h"
 #include "filelistviewitem.h"
-#include "svnqt/status.hpp"
-#include "svnqt/client.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/client.hpp"
 
 #include <klistview.h>
 #include <kurl.h>
+#include <ktrader.h>
 #include <qmap.h>
 #include <qptrlist.h>
 #include <qevent.h>
@@ -99,7 +100,8 @@ protected:
     template<class T> KDialogBase* createDialog(T**ptr,
         const QString&_head,
         bool OkCancel=false,
-        const char*name="dialog"
+        const char*name="dialog",
+        bool showHelp=false
         );
 
     FileListViewItemList* m_SelectedItems;
@@ -126,7 +128,9 @@ protected:
     virtual void contentsMouseMoveEvent( QMouseEvent *e );
     virtual void contentsWheelEvent( QWheelEvent * e );
     virtual void leaveEvent(QEvent*e);
-    virtual void rescanIconsRec(FileListViewItem*_parent=0,bool checkNewer=false);
+    virtual void rescanIconsRec(FileListViewItem*_parent=0,bool checkNewer=false,bool no_update=false);
+
+    KTrader::OfferList offersList(SvnItem*item,bool execOnly=false);
 
 private:
     KdesvnFileListPrivate*m_pList;
@@ -136,7 +140,7 @@ private:
 
 protected slots:
     virtual void slotSelectBrowsingRevision();
-    virtual void slotItemClicked(QListViewItem*);
+    virtual void slotItemRead(QListViewItem*);
     virtual void slotContextMenuRequested(QListViewItem *, const QPoint &, int);
     virtual void slotSelectionChanged();
     virtual void slotClientException(const QString&);
@@ -169,7 +173,7 @@ protected slots:
 signals:
     void sigLogMessage(const QString&);
     void changeCaption(const QString&);
-    void sigShowPopup(const QString&);
+    void sigShowPopup(const QString&,QWidget**);
     void sigUrlOpend(bool);
     void sigSwitchUrl(const KURL&);
     void sigUrlChanged(const QString&);
@@ -179,6 +183,7 @@ public slots:
     virtual void refreshCurrent(SvnItem*);
     virtual void closeMe();
     virtual void slotMkdir();
+    virtual void slotMkBaseDirs();
     virtual void slotSettingsChanged();
 
 protected slots:
@@ -203,7 +208,9 @@ protected slots:
     virtual void slotMakeRangeLog();
     virtual void slotMakeLog();
     virtual void slotMakeTree();
+    virtual void slotMakePartTree();
     virtual void slotInternalDrop();
+    virtual void slotOpenWith();
 
 private slots:
     void gotPreview( const KFileItem*, const QPixmap& );
