@@ -19,7 +19,9 @@
  ***************************************************************************/
 #include "mergedlg_impl.h"
 #include "rangeinput_impl.h"
-#include "svnqt/url.hpp"
+#include "src/svnqt/url.hpp"
+#include "helpers/ktranslateurl.h"
+#include "src/settings/kdesvnsettings.h"
 
 #include <kurlrequester.h>
 #include <kdialogbase.h>
@@ -32,24 +34,27 @@
 MergeDlg_impl::MergeDlg_impl(QWidget *parent, const char *name,bool src1,bool src2,bool out)
     :MergeDlg(parent, name)
 {
-    m_SrcOneInput->setMode(KFile::Directory);
+    m_SrcOneInput->setMode(KFile::Directory|KFile::File);
     if (!src1) {
         m_SrcOneInput->setEnabled(false);
         m_SrcOneInput->hide();
         m_SrcOneLabel->hide();
     }
-    m_SrcTwoInput->setMode(KFile::Directory);
+    m_SrcTwoInput->setMode(KFile::Directory|KFile::File);
     if (!src2) {
         m_SrcTwoInput->setEnabled(false);
         m_SrcTwoInput->hide();
         m_SrcTwoLabel->hide();
     }
-    m_OutInput->setMode(KFile::LocalOnly|KFile::Directory);
+    m_OutInput->setMode(KFile::LocalOnly|KFile::Directory|KFile::File);
     if (!out) {
         m_OutInput->setEnabled(false);
         m_OutInput->hide();
         m_OutLabel->hide();
     }
+    adjustSize();
+    setMinimumSize(minimumSizeHint());
+    m_useExternMerge->setChecked(Kdesvnsettings::extern_merge_default());
 }
 
 MergeDlg_impl::~MergeDlg_impl()
@@ -70,14 +75,8 @@ void MergeDlg_impl::setSrc1(const QString&what)
         } else {
             uri.setProtocol("");
         }
-    } else if (uri.protocol()=="http") {
-        uri.setProtocol("ksvn+http");
-    } else if (uri.protocol()=="https") {
-        uri.setProtocol("ksvn+https");
-    } else if (uri.protocol()=="svn") {
-        uri.setProtocol("ksvn");
-    } else if (uri.protocol()=="svn+ssh") {
-        uri.setProtocol("ksvn+ssh");
+    } else {
+        uri.setProtocol(helpers::KTranslateUrl::makeKdeUrl(uri.protocol()));
     }
     m_SrcOneInput->setURL(uri.url());
 }
@@ -95,14 +94,8 @@ void MergeDlg_impl::setSrc2(const QString&what)
         } else {
             uri.setProtocol("");
         }
-    } else if (uri.protocol()=="http") {
-        uri.setProtocol("ksvn+http");
-    } else if (uri.protocol()=="https") {
-        uri.setProtocol("ksvn+https");
-    } else if (uri.protocol()=="svn") {
-        uri.setProtocol("ksvn");
-    } else if (uri.protocol()=="svn+ssh") {
-        uri.setProtocol("ksvn+ssh");
+    } else {
+        uri.setProtocol(helpers::KTranslateUrl::makeKdeUrl(uri.protocol()));
     }
     m_SrcTwoInput->setURL(uri.url());
 }
@@ -138,6 +131,11 @@ bool MergeDlg_impl::dryrun()const
     return m_DryCheck->isChecked();
 }
 
+bool MergeDlg_impl::useExtern()const
+{
+    return m_useExternMerge->isChecked();
+}
+
 QString MergeDlg_impl::Src1()const
 {
     KURL uri(m_SrcOneInput->url());
@@ -182,12 +180,14 @@ Rangeinput_impl::revision_range MergeDlg_impl::getRange()const
     \fn MergeDlg_impl::getMergeRange(bool*force,bool*recursive,bool*related,bool*dry)
  */
 bool MergeDlg_impl::getMergeRange(Rangeinput_impl::revision_range&range,bool*force,bool*recursive,bool*ignorerelated,bool*dry,
+    bool*useExternal,
     QWidget*parent,const char*name)
 {
     MergeDlg_impl*ptr = 0;
     KDialogBase dlg(parent,name,true,i18n("Enter merge range"),
-            KDialogBase::Ok|KDialogBase::Cancel,
+            KDialogBase::Ok|KDialogBase::Cancel|KDialogBase::Help,
             KDialogBase::Ok,true);
+    dlg.setHelp("merging-items","kdesvn");
     QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
     ptr = new MergeDlg_impl(Dialog1Layout,"merge_range_dlg",false,false,false);
     dlg.resize( QSize(480,360).expandedTo(dlg.minimumSizeHint()) );
@@ -199,7 +199,15 @@ bool MergeDlg_impl::getMergeRange(Rangeinput_impl::revision_range&range,bool*for
     *recursive=ptr->recursive();
     *ignorerelated=ptr->ignorerelated();
     *dry = ptr->dryrun();
+    *useExternal = ptr->useExtern();
     return true;
 }
 
+void MergeDlg_impl::externDisplayToggled(bool how)
+{
+    m_DryCheck->setEnabled(!how);
+    m_RelatedCheck->setEnabled(!how);
+    m_ForceCheck->setEnabled(!how);
+}
+
 #include "mergedlg_impl.moc"
