@@ -1,9 +1,9 @@
 #ifndef _MODIFIED_THREAD_H
 #define _MODIFIED_THREAD_H
 
-#include "svnqt/client.hpp"
-#include "svnqt/revision.hpp"
-#include "svnqt/status.hpp"
+#include "src/svnqt/client.hpp"
+#include "src/svnqt/revision.hpp"
+#include "src/svnqt/status.hpp"
 #include "ccontextlistener.h"
 #include "eventnumbers.h"
 
@@ -25,8 +25,8 @@ public:
 protected:
     QMutex mutex;
     svn::Client* m_Svnclient;
-    svn::Context* m_CurrentContext;
-    smart_pointer<ThreadContextListener> m_SvnContext;
+    svn::ContextP m_CurrentContext;
+    svn::smart_pointer<ThreadContextListener> m_SvnContext;
     QObject*m_Parent;
     QString m_what;
     bool m_updates;
