@@ -19,6 +19,9 @@
  ***************************************************************************/
 #include "stopdlg.h"
 #include "ccontextlistener.h"
+#include "settings/kdesvnsettings.h"
+#include "helpers/stringhelper.h"
+
 #include <kapplication.h>
 #include <klocale.h>
 #include <kwin.h>
@@ -31,11 +34,14 @@
 #include <kdebug.h>
 #include <ktextbrowser.h>
 
-StopDlg::StopDlg(CContextListener*listener,QWidget *parent, const char *name,const QString&caption,const QString&text)
+StopDlg::StopDlg(QObject*listener,QWidget *parent, const char *name,const QString&caption,const QString&text)
  : KDialogBase(KDialogBase::Plain,caption,KDialogBase::Cancel, KDialogBase::Cancel,parent, name,true)
-    ,m_Context(listener),m_MinDuration(2000),mCancelled(false),mShown(false),m_BarShown(false)
+    ,m_Context(listener),m_MinDuration(1000),mCancelled(false),mShown(false),m_BarShown(false)
 {
     KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+    m_lastLogLines = 0;
+    m_lastLog = "";
+
     mShowTimer = new QTimer(this);
     m_StopTick.start();
     showButton(KDialogBase::Close, false);
@@ -48,15 +54,22 @@ StopDlg::StopDlg(CContextListener*listener,QWidget *parent, const char *name,con
     m_ProgressBar=new KProgress(15,mainWidget);
     m_ProgressBar->setCenterIndicator (false);
     m_ProgressBar->setTextEnabled(false);
-
     layout->addWidget(m_ProgressBar);
+    m_NetBar = new KProgress(15,mainWidget);
+    layout->addWidget(m_NetBar);
+
     mWait = false;
     m_LogWindow = 0;
 
     connect(mShowTimer, SIGNAL(timeout()), this, SLOT(slotAutoShow()));
     connect(m_Context,SIGNAL(tickProgress()),this,SLOT(slotTick()));
     connect(m_Context,SIGNAL(waitShow(bool)),this,SLOT(slotWait(bool)));
+    connect(m_Context,SIGNAL(netProgress(long long int, long long int)),
+        this,SLOT(slotNetProgres(long long int, long long int)));
+    connect(this,SIGNAL(sigCancel(bool)),m_Context,SLOT(setCanceled(bool)));
     mShowTimer->start(m_MinDuration, true);
+    setMinimumSize(280,160);
+    adjustSize();
 }
 
 void StopDlg::slotWait(bool how)
@@ -85,14 +98,16 @@ void StopDlg::slotAutoShow()
     }
     if (mShown||mWait||hasDialogs) {
         if (mWait) {
-            kdDebug() << "Waiting for show"<<endl;
+            //kdDebug() << "Waiting for show"<<endl;
             mShowTimer->start(m_MinDuration, true);
         }
         mShowTimer->start(m_MinDuration, true);
         return;
     }
     m_ProgressBar->hide();
+    m_NetBar->hide();
     m_BarShown=false;
+    m_netBarShown=false;
     show();
     kapp->processEvents();
     mShown = true;
@@ -102,7 +117,7 @@ void StopDlg::slotAutoShow()
 void StopDlg::slotCancel()
 {
     mCancelled = true;
-    m_Context->setCanceled(true);
+    emit sigCancel(true);
 }
 
 bool StopDlg::cancelld()
@@ -112,33 +127,60 @@ bool StopDlg::cancelld()
 
 void StopDlg::slotTick()
 {
-    if (!m_BarShown) {
-        m_ProgressBar->show();
-        m_BarShown=true;
-    }
     if (m_StopTick.elapsed()>500) {
+        if (!m_BarShown) {
+            m_ProgressBar->show();
+            m_BarShown=true;
+        }
         if (m_ProgressBar->progress()==15) {
             m_ProgressBar->reset();
         } else {
             m_ProgressBar->setProgress(m_ProgressBar->progress()+1);
         }
         m_StopTick.restart();
+        kapp->processEvents();
     }
-    kapp->processEvents();
 }
 
 void StopDlg::slotExtraMessage(const QString&msg)
 {
+    ++m_lastLogLines;
     if (!m_LogWindow) {
         QFrame* mainWidget = plainPage();
         m_LogWindow = new KTextBrowser(mainWidget);
         layout->addWidget(m_LogWindow);
         m_LogWindow->show();
         resize( QSize(500, 400).expandedTo(minimumSizeHint()) );
+    }
+    if (m_lastLogLines >= Kdesvnsettings::self()->cmdline_log_minline() &&
+        isHidden() ) {
         slotAutoShow();
     }
     m_LogWindow->append(msg);
     kapp->processEvents();
 }
 
+void StopDlg::slotNetProgres(long long int current, long long int max)
+{
+    if (m_StopTick.elapsed()>300||(m_BarShown&&!m_netBarShown)) {
+        if (!m_netBarShown) {
+            m_NetBar->show();
+            m_netBarShown=true;
+        }
+        QString s1 = helpers::ByteToString()(current);
+        if (max > -1 && max != m_NetBar->totalSteps()) {
+            QString s2 = helpers::ByteToString()(max);
+            m_NetBar->setFormat(i18n("%1 of %2").arg(s1).arg(s2));
+            m_NetBar->setTotalSteps(max);
+        }
+        if (max == -1) {
+            m_NetBar->setFormat(i18n("%1 transferred.").arg(s1));
+            m_NetBar->setTotalSteps(current+1);
+        }
+        m_NetBar->setValue(current);
+        m_StopTick.restart();
+        kapp->processEvents();
+    }
+}
+
 #include "stopdlg.moc"
