@@ -20,9 +20,12 @@
 #ifndef SVNACTIONS_H
 #define SVNACTIONS_H
 
-#include "svnqt/client.hpp"
-#include "svnqt/revision.hpp"
-#include "helpers/smart_pointer.h"
+#include "src/svnqt/client.hpp"
+#include "src/svnqt/revision.hpp"
+#include "src/svnqt/smart_pointer.hpp"
+#include "src/svnqt/shared_pointer.hpp"
+
+#include "simple_logcb.h"
 
 #include <kurl.h>
 
@@ -44,6 +47,7 @@ class CheckUpdatesThread;
 namespace svn {
     class Context;
     class LogEntry;
+    class InfoEntry;
 }
 
 namespace KIO {
@@ -53,19 +57,22 @@ namespace KIO {
 /**
 @author Rajko Albrecht
 */
-class SvnActions : public QObject
+class SvnActions : public QObject,public SimpleLogCb
 {
     Q_OBJECT
 public:
-    SvnActions(ItemDisplay *parent, const char *name = 0);
+    SvnActions(ItemDisplay *parent, const char *name = 0,bool processes_blocked=false);
     ~SvnActions();
     void reInitClient();
     //svn::Client&svnClient(){return m_Svnclient;}
     svn::Client* svnclient();
     void prepareUpdate(bool ask);
-    template<class T> KDialogBase* createDialog(T**ptr,const QString&_head,bool OkCance=false,const char*name="standard_dialog");
-    void makeCat(const svn::Revision&start, const QString&what,const QString&disp,const svn::Revision&peg=svn::Revision::UNDEFINED);
-    QByteArray makeGet(const svn::Revision&start, const QString&what,const svn::Revision&peg=svn::Revision::UNDEFINED);
+    template<class T> KDialogBase* createDialog(T**ptr,const QString&_head,bool OkCance=false,const char*name="standard_dialog",bool showHelp=false,const QString&u1=QString::null);
+    QByteArray makeGet(const svn::Revision&start, const QString&what,
+        const svn::Revision&peg=svn::Revision::UNDEFINED,QWidget*dlgparent=0);
+    bool makeGet(const svn::Revision&start, const QString&what,const QString&target,
+        const svn::Revision&peg=svn::Revision::UNDEFINED,QWidget*dlgparent=0);
+
     bool addItems(const QValueList<svn::Path> &items,bool rec=false);
     bool addItems(const QStringList&w,bool rec=false);
     void checkAddItems(const QString&path,bool print_error_box=true);
@@ -97,19 +104,24 @@ public:
      * it must not contain a "file://" inside.
      * \param what item to display
      * \param rev Revision the item-path is available, intersting only when @a what is a repository item
+     * \param startr startrevision for log
+     * \param endr endrevision for log
      */
-    void makeTree(const QString&what,const svn::Revision&rev);
-    void makeLog(svn::Revision start,svn::Revision end,SvnItem*k,bool list_files=false,int limit = 0);
-    void makeLog(svn::Revision start,svn::Revision end,const QString&,bool list_files=false, int limit=0);
-    const svn::LogEntries * getLog(svn::Revision start,svn::Revision end,const QString&,bool list_files, int limit);
+    void makeTree(const QString&what,const svn::Revision&rev,
+        const svn::Revision&startr=svn::Revision(1),
+        const svn::Revision&endr=svn::Revision::HEAD);
+    void makeLog(const svn::Revision&start,const svn::Revision&end,SvnItem*k,bool list_files=false,int limit = 0);
+    void makeLog(const svn::Revision&start,const svn::Revision&end,const QString&,bool list_files=false, int limit=0);
+    svn::SharedPointer<svn::LogEntriesMap> getLog(const svn::Revision&start,const svn::Revision& end,const QString&,bool list_files, int limit);
+    virtual bool getSingleLog(svn::LogEntry&,const svn::Revision&,const QString&,const svn::Revision&,QString&root);
 
-    void makeBlame(svn::Revision start, svn::Revision end, SvnItem*k);
-    void makeBlame(svn::Revision start, svn::Revision end, const QString&);
+    void makeBlame(const svn::Revision&start, const svn::Revision&end, SvnItem*k);
+    void makeBlame(const svn::Revision&start, const svn::Revision&end, const QString&,QWidget*parent=0,const svn::Revision&peg=svn::Revision::UNDEFINED,SimpleLogCb*_acb=0);
     void makeUpdate(const QStringList&what,const svn::Revision&rev,bool recurse);
     bool makeSwitch(const QString&rUrl,const QString&tPath,const svn::Revision&r,bool rec = true);
     bool makeSwitch(const QString&path,const QString&what);
     bool makeRelocate(const QString&fUrl,const QString&tUrl,const QString&path,bool rec = true);
-    void makeCheckout(const QString&,const QString&,const svn::Revision&,bool,bool,bool);
+    bool makeCheckout(const QString&,const QString&,const svn::Revision&,bool,bool,bool,bool exp_rec=true, QWidget*p=0);
     void makeInfo(QPtrList<SvnItem> lst,const svn::Revision&,const svn::Revision&,bool recursive = true);
     void makeInfo(const QStringList&lst,const svn::Revision&,const svn::Revision&,bool recursive = true);
     bool makeCommit(const svn::Targets&);
@@ -119,6 +131,7 @@ public:
     QString getInfo(const QString&_what,const svn::Revision&rev,const svn::Revision&peg,bool recursive,bool all=true);
 
     QString makeMkdir(const QString&);
+    bool makeMkdir(const QStringList&,const QString&);
     bool isLocalWorkingCopy(const KURL&url,QString&_baseUri);
     bool createUpdateCache(const QString&what);
     bool checkUpdateCache(const QString&path)const;
@@ -139,14 +152,20 @@ public:
     bool makeMove(const QString&,const QString&,bool);
     bool makeMove(const KURL::List&,const QString&,bool);
 
+    virtual bool makeCleanup(const QString&);
+
+    bool get(const QString&what,const QString& to,const svn::Revision&rev,const svn::Revision&peg,QWidget*p);
+    bool singleInfo(const QString&what,const svn::Revision&rev,svn::InfoEntry&target);
 
 protected:
-    smart_pointer<SvnActionsData> m_Data;
+    svn::smart_pointer<SvnActionsData> m_Data;
 
     void CheckoutExport(bool _exp);
     void CheckoutExportCurrent(bool _exp);
     void makeAdd(bool rec);
     CheckModifiedThread*m_CThread,*m_UThread;
+    void makeDiffinternal(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
+    void makeDiffExternal(const QString&p1,const svn::Revision&start,const QString&p2,const svn::Revision&end,bool isDir,QWidget*p,bool rec=true);
 
 public slots:
     virtual void dispDiff(const QString&);
@@ -164,17 +183,19 @@ public slots:
     virtual void slotRevert();
     virtual void slotRevertItems(const QStringList&);
     virtual void slotSwitch();
-    virtual void slotCleanup(const QString&);
     virtual void slotResolved(const QString&);
-    virtual void makeDiff(const QString&,const svn::Revision&,const svn::Revision&);
-    virtual void makeDiff(const QStringList&,const svn::Revision&,const svn::Revision&);
+    virtual void makeDiff(const QString&,const svn::Revision&,const svn::Revision&,bool isDir);
     virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&);
-    virtual void makeNorecDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&);
+    virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,bool,QWidget*p);
+    virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
+    virtual void makeNorecDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
     virtual void slotImport(const QString&,const QString&,const QString&,bool);
     virtual void slotMergeWcRevisions(const QString&,const svn::Revision&,const svn::Revision&,bool,bool,bool,bool);
     virtual void slotMerge(const QString&,const QString&, const QString&,
         const svn::Revision&,const svn::Revision&,bool,bool,bool,bool);
+    void slotMergeExternal(const QString&src1,const QString&src2, const QString&target,const svn::Revision&rev1,const svn::Revision&rev2,bool);
     virtual void slotExtraLogMsg(const QString&);
+    void slotMakeCat(const svn::Revision&start, const QString&what,const QString&disp,const svn::Revision&peg,QWidget*dlgparent);
 
 signals:
     void clientException(const QString&);
@@ -191,6 +212,7 @@ protected slots:
     virtual void procClosed(KProcess*);
     virtual void checkModthread();
     virtual void checkUpdateThread();
+    virtual void receivedStderr(KProcess*,char*,int);
 };
 
 #endif
