@@ -21,15 +21,15 @@
 #include "svnitem.h"
 #include "svnactions.h"
 #include "kdesvn_part.h"
-#include "fronthelpers/settings.h"
+#include "src/settings/kdesvnsettings.h"
 #include "svnqt/status.hpp"
-#include "helpers/smart_pointer.h"
+#include "svnqt/smart_pointer.hpp"
 #include "helpers/sub2qt.h"
+#include "helpers/ktranslateurl.h"
 
 #include <kglobal.h>
 #include <klocale.h>
 #include <kiconloader.h>
-#include <kmimetype.h>
 #include <kdebug.h>
 #include <kiconeffect.h>
 #include <kfileitem.h>
@@ -41,7 +41,7 @@
 #include <qpainter.h>
 #include <qbitmap.h>
 
-class SvnItem_p:public ref_count
+class SvnItem_p:public svn::ref_count
 {
     friend class SvnItem;
 public:
@@ -50,6 +50,7 @@ public:
     virtual ~SvnItem_p();
     KFileItem*createItem(const svn::Revision&peg);
     const KURL& kdeName(const svn::Revision&);
+    KMimeType::Ptr mimeType(bool dir=false);
 
 protected:
     svn::Status m_Stat;
@@ -61,6 +62,7 @@ protected:
     KFileItem*m_fitem;
     bool isWc;
     svn::Revision lRev;
+    KMimeType::Ptr mptr;
 };
 
 SvnItem_p::SvnItem_p()
@@ -84,6 +86,7 @@ void SvnItem_p::init()
 {
     m_full = m_Stat.path();
     m_kdename="";
+    mptr = 0;
     lRev=svn::Revision::UNDEFINED;
     while (m_full.endsWith("/")) {
         /* dir name possible */
@@ -97,11 +100,26 @@ void SvnItem_p::init()
         m_short = m_full;
     }
     m_url = m_Stat.entry().url();
-    m_fullDate = helpers::sub2qt::apr_time2qt(m_Stat.entry().cmtDate());
+    m_fullDate = svn::DateTime(m_Stat.entry().cmtDate());
     m_infoText = QString::null;
     m_fitem = 0;
 }
 
+KMimeType::Ptr SvnItem_p::mimeType(bool dir)
+{
+    if (!mptr||m_kdename.isEmpty()) {
+        if (m_kdename.isEmpty()) {
+            kdeName(svn::Revision::UNDEFINED);
+        }
+        if (dir) {
+            mptr = KMimeType::mimeType("inode/directory");
+        } else {
+            mptr = KMimeType::findByURL(m_kdename,0,isWc,!isWc);
+        }
+    }
+    return mptr;
+}
+
 const KURL& SvnItem_p::kdeName(const svn::Revision&r)
 {
     isWc = QString::compare(m_Stat.entry().url(),m_Stat.path())!=0;
@@ -109,39 +127,14 @@ const KURL& SvnItem_p::kdeName(const svn::Revision&r)
     if (!(r==lRev)||m_kdename.isEmpty()) {
         lRev=r;
         if (!isWc) {
-            QString ouri =m_Stat.entry().url();
+            m_kdename = m_Stat.entry().url();
             QString proto;
-            QStringList l=QStringList::split(":",ouri);
-            if (ouri.startsWith("svn://")){
-                proto = "ksvn";
-            } else if (ouri.startsWith("svn+ssh://")){
-                proto = "ksvn+ssh";
-            } else {
-                proto = "ksvn+"+l[0];
-            }
+            proto = helpers::KTranslateUrl::makeKdeUrl(m_kdename.protocol());
             m_kdename.setProtocol(proto);
-            l = QStringList::split("://",ouri);
-            if (proto=="ksvn+file") {
-                if (l.size()>1) {
-                    m_kdename.setPath(l[1]);
-                }
-            } else if (l.size()>1){
-                l=QStringList::split("/",l[1]);
-                m_kdename.setHost(l[0]);
-                l.remove(l.begin());
-                m_kdename.setPath("/"+l.join("/"));
+            QString revstr= lRev.toString();
+            if (revstr.length()>0) {
+                m_kdename.setQuery("?rev="+revstr);
             }
-
-            QString revstr="";
-            if (lRev.kind()==svn::Revision::HEAD) {
-                revstr="HEAD";
-            } else if (lRev.kind()==svn_opt_revision_number) {
-                revstr=QString("%1").arg(lRev.revnum());
-            } else if (lRev.kind()==svn_opt_revision_date) {
-                QDateTime t = helpers::sub2qt::apr_time2qt(lRev.date());
-                revstr=QString("{%1}").arg(t.toString("yyyy-MM-dd"));
-            }
-            m_kdename.setQuery("?rev="+revstr);
         } else {
             m_kdename.setPath(m_Stat.path());
         }
@@ -310,17 +303,12 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
     QPixmap p;
     m_overlaycolor = false;
     m_bgColor = NONE;
-    bool _local = false;
     /* yes - different way to "isDir" above 'cause here we try to use the
        mime-features of KDE on ALL not just unversioned entries.
      */
     if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())==0) {
         /* remote access */
-        if (isDir()) {
-            p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("folder",KIcon::Desktop,size);
-        } else {
-            p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("unknown",KIcon::Desktop,size);
-        }
+        p = p_Item->mimeType(isDir())->pixmap(KIcon::Desktop,size,KIcon::DefaultState);
         if (isLocked()) {
             m_bgColor = LOCKED;
             QPixmap p2;
@@ -333,11 +321,8 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
             }
         }
     } else {
-        _local = true;
         if (isRemoteAdded()) {
-            kdDebug()<<"Remoteadded"<<endl;
             if (isDir()) {
-                kdDebug()<<"Remotedir"<<endl;
                 p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("folder",KIcon::Desktop,size);
             } else {
                 p = kdesvnPartFactory::instance()->iconLoader()->loadIcon("unknown",KIcon::Desktop,size);
@@ -528,3 +513,8 @@ const KURL&SvnItem::kdeName(const svn::Revision&r)
 {
     return p_Item->kdeName(r);
 }
+
+KMimeType::Ptr SvnItem::mimeType()
+{
+    return p_Item->mimeType(isDir());
+}
