@@ -21,8 +21,9 @@
 #ifndef __SVN_ITEM_H
 #define __SVN_ITEM_H
 
-#include "helpers/smart_pointer.h"
-#include "svnqt/status.hpp"
+#include "src/svnqt/smart_pointer.hpp"
+#include "src/svnqt/status.hpp"
+#include <kmimetype.h>
 #include <qstring.h>
 #include <qdatetime.h>
 #include <qpixmap.h>
@@ -50,6 +51,7 @@ public:
     virtual const QString&shortName()const;
     virtual const QString&Url()const;
     virtual const KURL&kdeName(const svn::Revision&);
+    virtual KMimeType::Ptr mimeType();
     virtual const QDateTime&fullDate()const;
     virtual bool isDir()const;
     virtual bool isVersioned()const;
@@ -92,7 +94,7 @@ protected:
         NEEDLOCK = 9
     };
     color_type m_bgColor;
-    smart_pointer<SvnItem_p> p_Item;
+    svn::smart_pointer<SvnItem_p> p_Item;
     virtual SvnActions*getWrapper()const = 0;
 
     static QPixmap internalTransform(const QPixmap&,int size);
