@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include "svnlogdlgimp.h"
-#include "fronthelpers/settings.h"
-#include "svnqt/log_entry.hpp"
+#include "src/settings/kdesvnsettings.h"
+#include "src/svnqt/log_entry.hpp"
 #include "helpers/sub2qt.h"
 #include "svnactions.h"
 
@@ -36,6 +36,8 @@
 
 #include <qdatetime.h>
 #include <qheader.h>
+#include <qsplitter.h>
+#include <qtextstream.h>
 
 #include <list>
 
@@ -55,11 +57,16 @@ public:
     void showChangedEntries(KListView*);
     unsigned int numChangedEntries(){return changedPaths.count();}
     void setChangedEntries(const svn::LogEntry&);
+    void setRealName(const QString&_n){_realName=_n;}
+    const QString&realName()const{return _realName;}
+
+    bool copiedFrom(QString&_n,long&rev)const;
+    static bool isParent(const QString&_par,const QString&tar);
 
 protected:
     svn_revnum_t _revision;
     QDateTime fullDate;
-    QString _message;
+    QString _message,_realName;
     QValueList<svn::LogChangePathEntry> changedPaths;
 };
 
@@ -69,11 +76,11 @@ const int LogListViewItem::COL_DATE = 3;
 const int LogListViewItem::COL_MSG = 4;
 
 LogListViewItem::LogListViewItem(KListView*_parent,const svn::LogEntry&_entry)
-    : INHERITED(_parent)
+    : INHERITED(_parent),_realName(QString::null)
 {
     setMultiLinesEnabled(false);
     _revision=_entry.revision;
-    fullDate=helpers::sub2qt::apr_time2qt(_entry.date);
+    fullDate=svn::DateTime(_entry.date);
     setText(COL_REV,QString("%1").arg(_revision));
     setText(COL_AUTHOR,_entry.author);
     setText(COL_DATE,helpers::sub2qt::apr_time2qtString(_entry.date));
@@ -87,6 +94,7 @@ LogListViewItem::LogListViewItem(KListView*_parent,const svn::LogEntry&_entry)
     changedPaths = _entry.changedPaths;
     //setText(COL_MSG,_entry.message.c_str());
 }
+
 const QString&LogListViewItem::message()const
 {
     return _message;
@@ -125,6 +133,33 @@ void LogListViewItem::setChangedEntries(const svn::LogEntry&_entry)
     changedPaths = _entry.changedPaths;
 }
 
+bool LogListViewItem::copiedFrom(QString&_n,long&_rev)const
+{
+    for (unsigned i = 0; i < changedPaths.count();++i) {
+        if (changedPaths[i].action=='A' &&
+            !changedPaths[i].copyFromPath.isEmpty() &&
+            isParent(changedPaths[i].path,_realName)) {
+            kdDebug()<<_realName<< " - " << changedPaths[i].path << endl;
+            QString tmpPath = _realName;
+            QString r = _realName.mid(changedPaths[i].path.length());
+            _n=changedPaths[i].copyFromPath;
+            _n+=r;
+            _rev = changedPaths[i].copyFromRevision;
+            kdDebug()<<"Found switch from  "<< changedPaths[i].copyFromPath << " rev "<<changedPaths[i].copyFromRevision<<endl;
+            kdDebug()<<"Found switch from  "<< _n << " rev "<<_rev<<endl;
+            return true;
+        }
+    }
+    return false;
+}
+
+bool LogListViewItem::isParent(const QString&_par,const QString&tar)
+{
+    if (_par==tar) return true;
+    QString par = _par+(_par.endsWith("/")?"":"/");
+    return tar.startsWith(par);
+}
+
 SvnLogDlgImp::SvnLogDlgImp(SvnActions*ac,QWidget *parent, const char *name)
     :SvnLogDialogData(parent, name),_name("")
 {
@@ -134,21 +169,66 @@ SvnLogDlgImp::SvnLogDlgImp(SvnActions*ac,QWidget *parent, const char *name)
     m_ControlKeyDown = false;
     m_first = 0;
     m_second = 0;
-    if (Settings::self()->log_always_list_changed_files()) {
+
+    if (Kdesvnsettings::self()->log_always_list_changed_files()) {
         buttonListFiles->hide();
     } else {
         m_ChangedList->hide();
     }
     m_Actions = ac;
+    KConfigGroup cs(Kdesvnsettings::self()->config(), groupName);
+    QString t1 = cs.readEntry("logsplitter",QString::null);
+    if (!t1.isEmpty()) {
+        if (cs.readBoolEntry("laststate",false)==m_ChangedList->isHidden()) {
+            QTextStream st2(&t1,IO_ReadOnly);
+            st2 >> *m_centralSplitter;
+        }
+    }
 }
 
-void SvnLogDlgImp::dispLog(const svn::LogEntries*_log,const QString & what)
+SvnLogDlgImp::~SvnLogDlgImp()
+{
+    QString t1,t2;
+    QTextStream st1(&t1,IO_WriteOnly);
+    st1 << *m_centralSplitter;
+    KConfigGroup cs(Kdesvnsettings::self()->config(), groupName);
+    cs.writeEntry("logsplitter",t1);
+    cs.writeEntry("laststate",m_ChangedList->isHidden());
+}
+
+void SvnLogDlgImp::dispLog(const svn::SharedPointer<svn::LogEntriesMap>&_log,const QString & what,const QString&root)
 {
     if (!_log) return;
-    svn::LogEntries::const_iterator lit;
+    _base = root;
+    m_Entries = _log;
+    kdDebug()<<"What: "<<what << endl;
+    svn::LogEntriesMap::const_iterator lit;
     LogListViewItem * item;
+    QMap<long int,QString> namesMap;
+    QMap<long int,LogListViewItem*> itemMap;
+    long min,max;
+    min = max = -1;
     for (lit=_log->begin();lit!=_log->end();++lit) {
-        item = new LogListViewItem(m_LogView,*lit);
+        item = new LogListViewItem(m_LogView,(*lit));
+        if ((*lit).revision>max) max = (*lit).revision;
+        if ((*lit).revision<min || min == -1) min = (*lit).revision;
+        itemMap[(*lit).revision]=item;
+    }
+    if (itemMap.count()==0) {
+        return;
+    }
+    QString bef = what;
+    long rev;
+    // YES! I'd checked it: this is much faster than getting list of keys
+    // and iterating over that list!
+    for (long c=max;c>-1;--c) {
+        if (!itemMap.contains(c)) {
+            continue;
+        }
+        if (itemMap[c]->realName().isEmpty()) {
+            itemMap[c]->setRealName(bef);
+        }
+        itemMap[c]->copiedFrom(bef,rev);
     }
     _name = what;
 }
@@ -162,6 +242,7 @@ void SvnLogDlgImp::slotSelectionChanged(QListViewItem*_it)
     if (!_it) {
         m_DispPrevButton->setEnabled(false);
         buttonListFiles->setEnabled(false);
+        buttonBlame->setEnabled(false);
         return;
     }
     LogListViewItem* k = static_cast<LogListViewItem*>( _it );
@@ -179,6 +260,7 @@ void SvnLogDlgImp::slotSelectionChanged(QListViewItem*_it)
     m_LogDisplay->setText(k->message());
     m_ChangedList->clear();
     k->showChangedEntries(m_ChangedList);
+    buttonBlame->setEnabled(true);
 
     k = static_cast<LogListViewItem*>(_it->nextSibling());
     if (!k) {
@@ -204,7 +286,10 @@ void SvnLogDlgImp::slotDispPrevious()
         m_DispPrevButton->setEnabled(false);
         return;
     }
-    emit makeDiff(_name,p->rev(),k->rev());
+    QString s,e;
+    s = _base+k->realName();
+    e = _base+p->realName();
+    emit makeDiff(e,p->rev(),s,k->rev(),this);
 }
 
 
@@ -215,11 +300,11 @@ void SvnLogDlgImp::saveSize()
 {
     int scnum = QApplication::desktop()->screenNumber(parentWidget());
     QRect desk = QApplication::desktop()->screenGeometry(scnum);
-    KConfigGroupSaver cs(Settings::self()->config(), groupName);
+    KConfigGroupSaver cs(Kdesvnsettings::self()->config(), groupName);
     QSize sizeToSave = size();
-    Settings::self()->config()->writeEntry( QString::fromLatin1("Width %1").arg( desk.width()),
+    Kdesvnsettings::self()->config()->writeEntry( QString::fromLatin1("Width %1").arg( desk.width()),
         QString::number( sizeToSave.width()), true, false);
-    Settings::self()->config()->writeEntry( QString::fromLatin1("Height %1").arg( desk.height()),
+    Kdesvnsettings::self()->config()->writeEntry( QString::fromLatin1("Height %1").arg( desk.height()),
         QString::number( sizeToSave.height()), true, false);
 }
 
@@ -230,9 +315,9 @@ QSize SvnLogDlgImp::dialogSize()
     QRect desk = QApplication::desktop()->screenGeometry(scnum);
     w = sizeHint().width();
     h = sizeHint().height();
-    KConfigGroupSaver cs(Settings::self()->config(), groupName);
-    w = Settings::self()->config()->readNumEntry( QString::fromLatin1("Width %1").arg( desk.width()), w );
-    h = Settings::self()->config()->readNumEntry( QString::fromLatin1("Height %1").arg( desk.height()), h );
+    KConfigGroupSaver cs(Kdesvnsettings::self()->config(), groupName);
+    w = Kdesvnsettings::self()->config()->readNumEntry( QString::fromLatin1("Width %1").arg( desk.width()), w );
+    h = Kdesvnsettings::self()->config()->readNumEntry( QString::fromLatin1("Height %1").arg( desk.height()), h );
     return( QSize( w, h ) );
 }
 
@@ -271,7 +356,18 @@ void SvnLogDlgImp::slotItemClicked(int button,QListViewItem*item,const QPoint &,
 void SvnLogDlgImp::slotDispSelected()
 {
     if (!m_first || !m_second) return;
-    emit makeDiff(_name,m_first->rev(),m_second->rev());
+    emit makeDiff(_base+m_first->realName(),m_first->rev(),_base+m_second->realName(),m_second->rev(),this);
+}
+
+bool SvnLogDlgImp::getSingleLog(svn::LogEntry&t,const svn::Revision&r,const QString&what,const svn::Revision&peg,QString&root)
+{
+    root = _base;
+    if (m_Entries->find(r.revnum()) == m_Entries->end())
+    {
+        return m_Actions->getSingleLog(t,r,what,peg,root);
+    }
+    t=(*m_Entries)[r.revnum()];
+    return true;
 }
 
 void SvnLogDlgImp::slotListEntries()
@@ -281,17 +377,16 @@ void SvnLogDlgImp::slotListEntries()
         buttonListFiles->setEnabled(false);
         return;
     }
-    const svn::LogEntries*_log = m_Actions->getLog(it->rev(),it->rev(),_name,true,0);
+    svn::SharedPointer<svn::LogEntriesMap>_log = m_Actions->getLog(it->rev(),it->rev(),_name,true,0);
     if (!_log) {
         return;
     }
     if (_log->count()>0) {
-        it->setChangedEntries((*_log)[0]);
+        it->setChangedEntries((*_log)[it->rev()]);
         it->showChangedEntries(m_ChangedList);
         if (!m_ChangedList->isVisible()) m_ChangedList->show();
     }
     buttonListFiles->setEnabled(false);
-    delete _log;
 }
 
 void SvnLogDlgImp::keyPressEvent (QKeyEvent * e)
@@ -312,4 +407,20 @@ void SvnLogDlgImp::keyReleaseEvent (QKeyEvent * e)
     SvnLogDialogData::keyReleaseEvent(e);
 }
 
+void SvnLogDlgImp::slotBlameItem()
+{
+    LogListViewItem* k = static_cast<LogListViewItem*>(m_LogView->selectedItem());
+    if (!k) {
+        buttonBlame->setEnabled(false);
+        return;
+    }
+    svn::Revision start(svn::Revision::START);
+    m_Actions->makeBlame(start,k->rev(),_base+k->realName(),kapp->activeModalWidget(),k->rev(),this);
+}
+
+void SvnLogDlgImp::slotEntriesSelectionChanged()
+{
+}
+
+
 #include "svnlogdlgimp.moc"
