@@ -21,24 +21,30 @@
 #define SVNLOGDLGIMP_H
 
 #include "svnlogdlg.h"
-#include "svnqt/log_entry.hpp"
-#include "svnqt/client.hpp"
+#include "simple_logcb.h"
+#include "src/svnqt/log_entry.hpp"
+#include "src/svnqt/client.hpp"
+#include "src/svnqt/shared_pointer.hpp"
 
 #include <qsize.h>
 
 class LogListViewItem;
 class SvnActions;
 
-class SvnLogDlgImp: public SvnLogDialogData {
+class SvnLogDlgImp: public SvnLogDialogData,public SimpleLogCb
+{
 Q_OBJECT
 public:
     SvnLogDlgImp(SvnActions*,QWidget *parent = 0, const char *name = 0);
-    void dispLog(const svn::LogEntries*,const QString&);
+    virtual ~SvnLogDlgImp();
+    void dispLog(const svn::SharedPointer<svn::LogEntriesMap>&,const QString&,const QString&);
     void saveSize();
     QSize dialogSize();
 
+    virtual bool getSingleLog(svn::LogEntry&t,const svn::Revision&r,const QString&what,const svn::Revision&peg,QString&root);
+
 signals:
-    void makeDiff(const QString&,const svn::Revision&,const svn::Revision&);
+    void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
 
 protected slots:
     virtual void slotSelectionChanged(QListViewItem*);
@@ -48,15 +54,19 @@ protected slots:
     virtual void slotItemClicked(int,QListViewItem*,const QPoint &,int);
 protected:
     QString _name;
+    QString _base;
     static const char* groupName;
     LogListViewItem *m_first,*m_second;
     SvnActions*m_Actions;
     bool m_ControlKeyDown;
     virtual void keyPressEvent (QKeyEvent * e);
     virtual void keyReleaseEvent (QKeyEvent * e);
+    virtual void slotBlameItem();
+    svn::SharedPointer<svn::LogEntriesMap> m_Entries;
 
 protected slots:
     virtual void slotListEntries();
+    virtual void slotEntriesSelectionChanged();
 };
 
 #endif
