@@ -20,13 +20,15 @@
 #include "tcontextlistener.h"
 
 #include "ccontextlistener.h"
-#include "authdialogimpl.h"
-#include "logmsg_impl.h"
-#include "ssltrustprompt_impl.h"
+#include "src/ksvnwidgets/authdialogimpl.h"
+#include "src/ksvnwidgets/logmsg_impl.h"
+#include "src/ksvnwidgets/ssltrustprompt_impl.h"
+#include "src/helpers/stringhelper.h"
 #include "threadcontextlistenerdata.h"
 
 #include <kapplication.h>
 #include <kdebug.h>
+#include <klocale.h>
 
 ThreadContextListener::ThreadContextListener(QObject* parent, const char* name)
     : CContextListener(parent, name)
@@ -136,6 +138,31 @@ void ThreadContextListener::contextNotify(const QString&aMsg)
     kapp->postEvent(this,ev);
 }
 
+/*!
+    \fn ThreadContextListener::contextProgress(long long int current, long long int max)
+ */
+void ThreadContextListener::contextProgress(long long int current, long long int max)
+{
+    if (current==0) {
+        return;
+    }
+    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_NOTIFY);
+    // receiver must delete data!
+    ThreadContextListenerData::snotify* _notify = new ThreadContextListenerData::snotify();
+    QString msg;
+    QString s1 = helpers::ByteToString()(current);
+    if (max>-1) {
+        QString s2 = helpers::ByteToString()(max);
+        msg = i18n("%1 of %2 transferred.").arg(s1).arg(s2);
+    } else {
+        msg = i18n("%1 transferred.").arg(s1);
+    }
+    _notify->msg = msg;
+    ev->setData((void*)_notify);
+    kapp->postEvent(this,ev);
+}
+
 void ThreadContextListener::sendTick()
 {
     QMutexLocker lock(&(m_Data->m_CallbackMutex));
