@@ -27,10 +27,11 @@
 #endif
 
 // svncpp
-#include "client.hpp"
-#include "client_impl.hpp"
+#include "svnqt/client.hpp"
+#include "svnqt/client_impl.hpp"
+#include "svnqt/svnqt_defines.hpp"
+
 #include "svn_opt.h"
-#include "svncpp_defines.hpp"
 
 namespace svn
 {
@@ -42,7 +43,7 @@ namespace svn
   {
   }
 
-  Client*Client::getobject(Context * context,int subtype)
+  Client*Client::getobject(ContextP context,int subtype)
   {
     switch(subtype) {
       case 0:
