@@ -36,7 +36,8 @@
 #pragma warning (disable: 4290)
 #endif
 
-#include "svncpp_defines.hpp"
+#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/svnstream.hpp"
 
 // qt
 #include <qglobal.h>
@@ -69,21 +70,12 @@ namespace svn
   class Targets;
   class DirEntry;
 
-#if QT_VERSION < 0x040000
-  typedef QValueList<LogEntry> LogEntries;
-  typedef QValueList<InfoEntry> InfoEntries;
-  typedef QValueList<Status> StatusEntries;
-  typedef QValueList<DirEntry> DirEntries;
-  typedef QValueList<AnnotateLine> AnnotatedFile;
-  typedef QValueList<Revision> Revisions;
-#else
-  typedef QList<LogEntry> LogEntries;
-  typedef QList<InfoEntry> InfoEntries;
-  typedef QList<Status> StatusEntries;
-  typedef QList<DirEntry> DirEntries;
-  typedef QList<AnnotateLine> AnnotatedFile;
-  typedef QList<Revision> Revisions;
-#endif
+  typedef QLIST<LogEntry> LogEntries;
+  typedef QLIST<InfoEntry> InfoEntries;
+  typedef QLIST<Status> StatusEntries;
+  typedef QLIST<DirEntry> DirEntries;
+  typedef QLIST<AnnotateLine> AnnotatedFile;
+  typedef QLIST<Revision> Revisions;
 
   // map of logentries - key is revision
   typedef QMap<long,LogEntry> LogEntriesMap;
@@ -92,16 +84,14 @@ namespace svn
   // pair of path, PropertiesMap
   typedef QPair<QString, PropertiesMap> PathPropertiesMapEntry;
   // vector of path, Properties pairs
-#if QT_VERSION < 0x040000
-  typedef QValueList<PathPropertiesMapEntry> PathPropertiesMapList;
-#else
-  typedef QList<PathPropertiesMapEntry> PathPropertiesMapList;
-#endif
+  typedef QLIST<PathPropertiesMapEntry> PathPropertiesMapList;
 
-  /**
-   * Subversion client API.
+  /** Subversion client API.
+   *
+   * Never use an object of this as global static! This will make problems with subversion
+   * initialize.
    */
-  SVNQT_EXPORT class Client
+  class SVNQT_EXPORT Client
   {
   public:
     /**
@@ -115,7 +105,7 @@ namespace svn
     /**
      * @return returns the Client context
      */
-    virtual const Context *
+    virtual const ContextP
     getContext () const = 0;
 
     /**
@@ -126,7 +116,7 @@ namespace svn
      * @param context new context to use
      */
     virtual void
-    setContext (Context * context = NULL) = 0;
+    setContext (ContextP context) = 0;
 
     /**
      * get a real instance. Result must cleaned with delete.
@@ -134,7 +124,7 @@ namespace svn
      * \param subtype the wanted implementation - this moment only 0 allowed.
      * \return an instance of client or 0L if error.
      */
-     static Client*getobject(Context * context = 0,int subtype=0);
+     static Client*getobject(ContextP context,int subtype=0);
 
     /**
      * Enumerates all files/dirs at a given path.
@@ -153,7 +143,7 @@ namespace svn
      * @return vector with Status entries.
      */
     virtual StatusEntries
-    status (const QString& path,
+    status (const Path& path,
             const bool descend = false,
             const bool get_all = true,
             const bool update = false,
@@ -173,7 +163,7 @@ namespace svn
      * @return a Status with Statis.isVersioned = FALSE
      */
     virtual Status
-    singleStatus (const QString& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException)=0;
+    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException)=0;
 
   /**
      * Executes a revision checkout.
@@ -187,7 +177,7 @@ namespace svn
      * @exception ClientException
      */
     virtual svn_revnum_t
-    checkout (const QString& moduleName, const Path & destPath,
+    checkout (const Path& moduleName, const Path & destPath,
               const Revision & revision,
               const Revision & peg = Revision::UNDEFINED,
               bool recurse = true,
@@ -245,7 +235,7 @@ namespace svn
      *                 Revision::HEAD will checkout the
      *                 latest revision.
      * @param recurse recursively update.
-     * @param ignore_external ignore externals (only when Subversion 1.2 or above)
+     * @param ignore_externals ignore externals (only when Subversion 1.2 or above)
      * @exception ClientException
      */
     virtual Revisions
@@ -265,6 +255,36 @@ namespace svn
     cat (const Path & path,
           const Revision & revision,
           const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+    /**
+     * Retrieves the contents for a specific @a revision of
+     * a @a path at @a peg_revision
+     *
+     * @param buffer Stream to store content direct
+     * @param path path of file or directory
+     * @param peg_revision revision to base the URL
+     * @param revision revision to retrieve
+     * @exception ClientException
+     */
+    virtual void
+    cat(svn::stream::SvnStream&buffer,
+            const Path & path,
+            const Revision & revision,
+            const Revision & peg_revision) throw (ClientException)=0;
+    /**
+     * Retrieves the contents for a specific @a revision of
+     * a @a path at @a peg_revision
+     *
+     * @param path path of file or directory
+     * @param target new (local) name
+     * @param peg_revision revision to base the URL
+     * @param revision revision to retrieve
+     * @param peg_revision Revision to look at
+     */
+    virtual void
+    get (const Path & path,
+          const QString  & target,
+          const Revision & revision,
+          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -324,7 +344,7 @@ namespace svn
      * the callback asks for a logmessage.
      *
      * @param path
-     * @param message log message. This parameter will be ignored!
+     * @param message log message. if it is QString::null asks when working on repository
      * @exception ClientException
      */
     virtual void
@@ -337,7 +357,7 @@ namespace svn
      * the callback asks for a logmessage.
      *
      * @param targets encoded pathes to create
-     * @param message log message. This parameter will be ignored!
+     * @param message log message. if it is QString::null asks when working on repository
      * @exception ClientException
      */
     virtual void
@@ -435,7 +455,7 @@ namespace svn
      * @since subversion 1.2
      */
     virtual InfoEntries
-    info(const QString &path,
+    info(const Path &path,
           bool rec,
           const Revision & rev,
           const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
@@ -455,8 +475,8 @@ namespace svn
      * @param limit (ignored when subversion 1.1 API)
      * @return a vector with log entries
      */
-    virtual const LogEntries *
-    log (const QString& path, const Revision & revisionStart,
+    virtual LogEntries *
+    log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          bool discoverChangedPaths=false,
          bool strictNodeHistory=true,int limit = 0) throw (ClientException)=0;
@@ -469,7 +489,7 @@ namespace svn
      * You can use the constants Revision::START and
      * Revision::HEAD
      *
-     * @param path
+     * @param path Path to make a log for
      * @param revisionStart
      * @param revisionEnd
      * @param target the logmap where to store the entries
@@ -479,7 +499,7 @@ namespace svn
      * @return true if success
      */
     virtual bool
-    log (const QString& path, const Revision & revisionStart,
+    log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          LogEntriesMap&target,
          bool discoverChangedPaths=false,
@@ -502,12 +522,12 @@ namespace svn
      * @param recurse whether the operation should be done recursively.
      * @param ignoreAncestry whether the files will be checked for
      * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated
-     * on deleted files.
+     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
+     * @param ignore_contenttype if true generate diff even the items are marked as binaries
      * @return delta between the files
      * @exception ClientException
      */
-    virtual QString
+    virtual QByteArray
     diff (const Path & tmpPath, const Path & path,
           const Revision & revision1, const Revision & revision2,
           const bool recurse, const bool ignoreAncestry,
@@ -523,18 +543,19 @@ namespace svn
      * @param tmpPath prefix for a temporary directory needed by diff.
      * Filenames will have ".tmp" and similar added to this prefix in
      * order to ensure uniqueness.
-     * @param path path of the file.
-     * @param revision1 one of the revisions to check.
-     * @param revision2 the other revision.
+     * @param path1 first file or folder to diff.
+     * @param path2 second file or folder to diff.
+     * @param revision1 one of the revisions to check (path1).
+     * @param revision2 the other revision (path2).
      * @param recurse whether the operation should be done recursively.
      * @param ignoreAncestry whether the files will be checked for
      * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated
-     * on deleted files.
+     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
+     * @param ignore_contenttype if true generate diff even the items are marked as binaries
      * @return delta between the files
      * @exception ClientException
      */
-    virtual QString
+    virtual QByteArray
     diff (const Path & tmpPath, const Path & path1,const Path & path2,
           const Revision & revision1, const Revision & revision2,
           const bool recurse, const bool ignoreAncestry,
@@ -555,7 +576,7 @@ namespace svn
      *         a relative path (only filename)
      */
     virtual DirEntries
-    list (const QString& pathOrUrl,
+    list (const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
           bool recurse,bool retrieve_locks) throw (ClientException)=0;
@@ -602,8 +623,8 @@ namespace svn
      * @param revision
      * @param propName
      * @param propValue
-     * @param skip_check if true skip validity checks
      * @param recurse
+     * @param skip_checks if true skip validity checks
      * @return PropertiesList
      */
     virtual void
