@@ -26,8 +26,8 @@
 #ifndef _SVNCPP_CLIENT_IMPL_H_
 #define _SVNCPP_CLIENT_IMPL_H_
 
-#include "client.hpp"
-#include "svncpp_defines.hpp"
+#include "svnqt/client.hpp"
+#include "svnqt/svnqt_defines.hpp"
 
 // Ignore MSVC 6 compiler warning: debug symbol truncated
 #if defined (_MSC_VER) && _MSC_VER <= 1200
@@ -40,23 +40,27 @@
 #endif
 namespace svn
 {
+  namespace stream {
+    class SvnStream;
+  }
+
   /**
    * Subversion client API.
    */
-  SVNQT_NOEXPORT class Client_impl:public Client
+  class SVNQT_NOEXPORT Client_impl:public Client
   {
   public:
     /**
      * Initializes the primary memory pool.
      */
-    Client_impl(Context * context = 0);
+    Client_impl(ContextP context);
 
     virtual ~Client_impl();
 
     /**
      * @return returns the Client context
      */
-    virtual const Context *
+    virtual const ContextP
     getContext () const;
 
     /**
@@ -67,7 +71,7 @@ namespace svn
      * @param context new context to use
      */
     virtual void
-    setContext (Context * context = NULL);
+    setContext (ContextP context);
 
 
     /**
@@ -87,7 +91,7 @@ namespace svn
      * @return vector with Status entries.
      */
     virtual StatusEntries
-    status (const QString& path,
+    status (const Path& path,
             const bool descend = false,
             const bool get_all = true,
             const bool update = false,
@@ -107,7 +111,7 @@ namespace svn
      * @return a Status with Statis.isVersioned = FALSE
      */
     virtual Status
-    singleStatus (const QString& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
+    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
 
   /**
      * Executes a revision checkout.
@@ -121,7 +125,7 @@ namespace svn
      * @exception ClientException
      */
     virtual svn_revnum_t
-    checkout (const QString& moduleName, const Path & destPath,
+    checkout (const Path& moduleName, const Path & destPath,
               const Revision & revision,
               const Revision & peg = Revision::UNDEFINED,
               bool recurse = true,
@@ -179,7 +183,7 @@ namespace svn
      *                 Revision::HEAD will checkout the
      *                 latest revision.
      * @param recurse recursively update.
-     * @param ignore_external ignore externals (only when Subversion 1.2 or above)
+     * @param ignore_externals ignore externals (only when Subversion 1.2 or above)
      * @exception ClientException
      */
     virtual Revisions
@@ -193,12 +197,44 @@ namespace svn
      * @param path path of file or directory
      * @param peg_revision revision to base the URL
      * @param revision revision to retrieve
+     * @param peg_revision Revision to look at
      * @return contents of the file
      */
     virtual QByteArray
     cat (const Path & path,
           const Revision & revision,
           const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
+    /**
+     * Retrieves the contents for a specific @a revision of
+     * a @a path at @a peg_revision
+     *
+     * @param buffer Stream to store content direct
+     * @param path path of file or directory
+     * @param peg_revision revision to base the URL
+     * @param revision revision to retrieve
+     * @exception ClientException
+     */
+    virtual void
+    cat(svn::stream::SvnStream&buffer,
+            const Path & path,
+            const Revision & revision,
+            const Revision & peg_revision) throw (ClientException);
+
+    /**
+     * Retrieves the contents for a specific @a revision of
+     * a @a path at @a peg_revision
+     *
+     * @param path path of file or directory
+     * @param target new (local) name
+     * @param peg_revision revision to base the URL
+     * @param revision revision to retrieve
+     * @param peg_revision Revision to look at
+     */
+    virtual void
+    get (const Path & path,
+          const QString  & target,
+          const Revision & revision,
+          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -258,7 +294,7 @@ namespace svn
      * the callback asks for a logmessage.
      *
      * @param path
-     * @param message log message. This parameter will be ignored!
+     * @param message log message. if it is QString::null asks when working on repository
      * @exception ClientException
      */
     virtual void
@@ -271,7 +307,7 @@ namespace svn
      * the callback asks for a logmessage.
      *
      * @param targets encoded pathes to create
-     * @param message log message. This parameter will be ignored!
+     * @param message log message. if it is QString::null asks when working on repository
      * @exception ClientException
      */
     virtual void
@@ -367,7 +403,7 @@ namespace svn
      * @since subversion 1.2
      */
     virtual InfoEntries
-    info(const QString &path,
+    info(const Path &path,
           bool rec,
           const Revision & rev,
           const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
@@ -387,8 +423,8 @@ namespace svn
      * @param limit (ignored when subversion 1.1 API)
      * @return a vector with log entries
      */
-    virtual const LogEntries *
-    log (const QString& path, const Revision & revisionStart,
+    virtual LogEntries *
+    log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          bool discoverChangedPaths=false,
          bool strictNodeHistory=true,int limit = 0) throw (ClientException);
@@ -410,7 +446,7 @@ namespace svn
      * @return true if success
      */
     virtual bool
-    log (const QString& path, const Revision & revisionStart,
+    log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          LogEntriesMap&target,
          bool discoverChangedPaths=false,
@@ -435,10 +471,11 @@ namespace svn
      * relatedness.
      * @param noDiffDeleted if true, no diff output will be generated
      * on deleted files.
+     * @param ignore_contenttype if true generate diff even the items are marked as binaries
      * @return delta between the files
      * @exception ClientException
      */
-    virtual QString
+    virtual QByteArray
     diff (const Path & tmpPath, const Path & path,
           const Revision & revision1, const Revision & revision2,
           const bool recurse, const bool ignoreAncestry,
@@ -454,18 +491,19 @@ namespace svn
      * @param tmpPath prefix for a temporary directory needed by diff.
      * Filenames will have ".tmp" and similar added to this prefix in
      * order to ensure uniqueness.
-     * @param path path of the file.
-     * @param revision1 one of the revisions to check.
-     * @param revision2 the other revision.
+     * @param path1 first file or folder to diff.
+     * @param path2 second file or folder to diff.
+     * @param revision1 one of the revisions to check (path1).
+     * @param revision2 the other revision (path2).
      * @param recurse whether the operation should be done recursively.
      * @param ignoreAncestry whether the files will be checked for
      * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated
-     * on deleted files.
+     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
+     * @param ignore_contenttype if true generate diff even the items are marked as binaries
      * @return delta between the files
      * @exception ClientException
      */
-    virtual QString
+    virtual QByteArray
     diff (const Path & tmpPath, const Path & path1,const Path & path2,
           const Revision & revision1, const Revision & revision2,
           const bool recurse, const bool ignoreAncestry,
@@ -484,7 +522,7 @@ namespace svn
      *         a relative path (only filename)
      */
     virtual DirEntries
-    list (const QString& pathOrUrl,
+    list (const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
           bool recurse,bool retrieve_locks) throw (ClientException);
@@ -497,7 +535,6 @@ namespace svn
      * @param revision
      * @param peg most case should set to @a revision
      * @param recurse
-     * @param skip_check if true skip validity checks
      * @return PropertiesList
      */
     virtual PathPropertiesMapList
@@ -533,6 +570,7 @@ namespace svn
      * @param propName
      * @param propValue
      * @param recurse
+     * @param skip_check if true skip validity checks
      * @return PropertiesList
      */
     virtual void
@@ -652,7 +690,7 @@ namespace svn
     };
 
   private:
-    Context * m_context;
+    ContextP m_context;
 
     /**
      * disallow assignment operator
@@ -665,15 +703,20 @@ namespace svn
     Client_impl (const Client &);
 
     DirEntries
-    list_simple(const QString& pathOrUrl,
+    list_simple(const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
           bool recurse) throw (ClientException);
     DirEntries
-    list_locks(const QString& pathOrUrl,
+    list_locks(const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
           bool recurse) throw (ClientException);
+
+    svn_error_t * internal_cat(const Path & path,
+                const Revision & revision,
+                const Revision & peg_revision,
+                svn::stream::SvnStream&);
   };
 
 }
