@@ -28,7 +28,7 @@
 
 
 // svncpp
-#include "client_impl.hpp"
+#include "svnqt/client_impl.hpp"
 
 // Subversion api
 #include "svn_client.h"
@@ -36,15 +36,15 @@
 #include "svn_path.h"
 //#include "svn_utf.h"
 
-#include "dirent.hpp"
-#include "exception.hpp"
-#include "pool.hpp"
-#include "status.hpp"
-#include "targets.hpp"
-#include "info_entry.hpp"
-#include "url.hpp"
-#include "svncpp_defines.hpp"
-#include "context_listener.hpp"
+#include "svnqt/dirent.hpp"
+#include "svnqt/exception.hpp"
+#include "svnqt/pool.hpp"
+#include "svnqt/status.hpp"
+#include "svnqt/targets.hpp"
+#include "svnqt/info_entry.hpp"
+#include "svnqt/url.hpp"
+#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/context_listener.hpp"
 
 namespace svn
 {
@@ -76,11 +76,12 @@ namespace svn
            hi != NULL;
            hi = apr_hash_next (hi))
       {
-        char *path;
+        const void *pv;
         void *val;
-        apr_hash_this (hi, (const void **) &path, NULL, &val);
+        apr_hash_this (hi, &pv, NULL, &val);
 
         svn_log_changed_path_t *log_item = reinterpret_cast<svn_log_changed_path_t *> (val);
+        const char* path = reinterpret_cast<const char*>(pv);
 
         entry.changedPaths.push_back (
               LogChangePathEntry (path,
@@ -122,11 +123,12 @@ namespace svn
            hi != NULL;
            hi = apr_hash_next (hi))
       {
-        char *path;
+        const void *pv;
         void *val;
-        apr_hash_this (hi, (const void **) &path, NULL, &val);
+        apr_hash_this (hi, &pv, NULL, &val);
 
         svn_log_changed_path_t *log_item = reinterpret_cast<svn_log_changed_path_t *> (val);
+        const char* path = reinterpret_cast<const char*>(pv);
 
         entry.changedPaths.push_back (
               LogChangePathEntry (path,
@@ -154,7 +156,7 @@ namespace svn
   static svn_error_t * InfoEntryFunc(void*baton,
                             const char*path,
                             const svn_info_t*info,
-                            apr_pool_t *pool)
+                            apr_pool_t *)
   {
     StatusEntriesBaton* seb = (StatusEntriesBaton*)baton;
     if (seb->m_Context) {
@@ -184,7 +186,7 @@ namespace svn
   }
 
   static StatusEntries
-  localStatus (const QString& path,
+  localStatus (const Path& path,
                const bool descend,
                const bool get_all,
                const bool update,
@@ -205,7 +207,7 @@ namespace svn
     baton.pool = pool;
     error = svn_client_status2 (
       &revnum,      // revnum
-      path.TOUTF8(),         // path
+      path.path().TOUTF8(),         // path
       rev,
       StatusEntriesFunc, // status func
       &baton,        // status baton
@@ -244,39 +246,37 @@ namespace svn
   }
 
   static Status
-  dirEntryToStatus (const QString& path, const DirEntry & dirEntry)
+  dirEntryToStatus (const Path& path, const DirEntry & dirEntry)
   {
-    QString url = path;
-    url += QString::fromUtf8("/");
+    QString url = path.path();
+    url += QString::FROMUTF8("/");
     url += dirEntry.name();
     return Status (url, dirEntry);
   }
 
   static Status
-  infoEntryToStatus(const QString&path,const InfoEntry&infoEntry)
+  infoEntryToStatus(const Path&,const InfoEntry&infoEntry)
   {
     return Status(infoEntry.url(),infoEntry);
   }
 
   static StatusEntries
   remoteStatus (Client * client,
-                const QString& path,
+                const Path& path,
                 const bool descend,
-                const bool get_all,
-                const bool update,
-                const bool no_ignore,
+                const bool ,
+                const bool ,
+                const bool ,
                 const Revision revision,
-                Context * context,
+                Context * ,
                 bool detailed_remote)
   {
     DirEntries dirEntries = client->list(path, revision, revision, descend,detailed_remote);
     DirEntries::const_iterator it;
 
     StatusEntries entries;
-    QString url = path;
-    url+=QString::fromUtf8("/");
-    bool _det = detailed_remote;
-
+    QString url = path.path();
+    url+=QString::FROMUTF8("/");
 
     for (it = dirEntries.begin (); it != dirEntries.end (); it++)
     {
@@ -288,7 +288,7 @@ namespace svn
   }
 
   StatusEntries
-  Client_impl::status (const QString& path,
+  Client_impl::status (const Path& path,
                   const bool descend,
                   const bool get_all,
                   const bool update,
@@ -297,16 +297,17 @@ namespace svn
                   bool detailed_remote,
                   const bool hide_externals) throw (ClientException)
   {
-    if (Url::isValid (path))
-      return remoteStatus (this, path, descend, get_all, update,
+    if (Url::isValid (path.path())) {
+        return remoteStatus (this, path, descend, get_all, update,
                            no_ignore,revision,m_context,detailed_remote);
-    else
+    } else {
       return localStatus (path, descend, get_all, update,
                           no_ignore, hide_externals, m_context);
+    }
   }
 
   static Status
-  localSingleStatus (const QString& path, Context * context,bool update=false)
+  localSingleStatus (const Path& path, Context * context,bool update=false)
   {
     svn_error_t *error;
     apr_hash_t *status_hash;
@@ -321,7 +322,7 @@ namespace svn
 
     error = svn_client_status2 (
       &revnum,      // revnum
-      path.TOUTF8(),         // path
+      path.path().TOUTF8(),         // path
       rev,
       StatusEntriesFunc, // status func
       &baton,        // status baton
@@ -353,7 +354,7 @@ namespace svn
   };
 
   static Status
-  remoteSingleStatus (Client * client, const QString& path,const Revision revision, Context * context)
+  remoteSingleStatus (Client * client, const Path& path,const Revision revision, Context * )
   {
     InfoEntries infoEntries = client->info(path,false,revision,Revision(Revision::UNDEFINED));
     if (infoEntries.size () == 0)
@@ -363,16 +364,16 @@ namespace svn
   }
 
   Status
-  Client_impl::singleStatus (const QString& path,bool update,const Revision revision) throw (ClientException)
+  Client_impl::singleStatus (const Path& path,bool update,const Revision revision) throw (ClientException)
   {
-    if (Url::isValid (path))
+    if (Url::isValid (path.path()))
       return remoteSingleStatus (this, path,revision, m_context);
     else
       return localSingleStatus (path, m_context,update);
   }
 
   bool
-  Client_impl::log (const QString& path, const Revision & revisionStart,
+  Client_impl::log (const Path& path, const Revision & revisionStart,
        const Revision & revisionEnd,
        LogEntriesMap&log_target,
        bool discoverChangedPaths,
@@ -404,8 +405,8 @@ namespace svn
     return true;
   }
 
-  const LogEntries *
-  Client_impl::log (const QString& path, const Revision & revisionStart,
+  LogEntries *
+  Client_impl::log (const Path& path, const Revision & revisionStart,
                const Revision & revisionEnd, bool discoverChangedPaths,
                bool strictNodeHistory,int limit) throw (ClientException)
   {
@@ -440,7 +441,7 @@ namespace svn
   }
 
   InfoEntries
-  Client_impl::info(const QString& path,
+  Client_impl::info(const Path& _p,
                 bool rec,
                 const Revision & rev,
                 const Revision & peg_revision) throw (ClientException)
@@ -456,7 +457,6 @@ namespace svn
     baton.pool = pool;
     baton.m_Context=m_context;
     svn_opt_revision_t pegr;
-    Path _p(path);
     const char *truepath;
     bool internal_peg = false;
     error = svn_opt_parse_path (&pegr, &truepath,
@@ -465,9 +465,9 @@ namespace svn
     if (error != NULL)
       throw ClientException (error);
 
-    
+
     if (peg_revision.kind() == svn_opt_revision_unspecified) {
-        if ((svn_path_is_url (path.TOUTF8())) && (pegr.kind == svn_opt_revision_unspecified)) {
+        if ((svn_path_is_url (_p.cstr())) && (pegr.kind == svn_opt_revision_unspecified)) {
             pegr.kind = svn_opt_revision_head;
             internal_peg=true;
         }
@@ -482,6 +482,8 @@ namespace svn
                       rec,
                       *m_context,    //client ctx
                       pool);
+    if (error != NULL)
+      throw ClientException (error);
 
     apr_array_header_t *statusarray =
       svn_sort__hash (status_hash, svn_sort_compare_items_as_paths,
