@@ -6,15 +6,15 @@
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library (in the file LGPL.txt); if not, 
- * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * License along with this library (in the file LGPL.txt); if not,
+ * write to the Free Software Foundation, Inc., 51 Franklin St,
  * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
@@ -42,6 +42,12 @@ namespace svn
   {
   }
 
+  DateTime::DateTime(const QDateTime&dt)
+    : m_time(0)
+  {
+    apr_time_ansi_put(&m_time,dt.toTime_t());
+  }
+
   DateTime::DateTime (const DateTime & dateTime)
   : m_time(dateTime.m_time)
   {
@@ -54,6 +60,25 @@ namespace svn
     return *this;
   }
 
+  const bool DateTime::operator<(const DateTime&dateTime)const
+  {
+    return m_time<dateTime.m_time;
+  }
+
+  const bool DateTime::operator>(const DateTime&dateTime)const
+  {
+    return dateTime<*this;
+  }
+
+  const bool DateTime::operator!=(const DateTime&dateTime)const
+  {
+    return *this<dateTime||dateTime<*this;
+  }
+  const bool DateTime::operator==(const DateTime&dateTime)const
+  {
+    return !(*this!=dateTime);
+  }
+
   const bool
   DateTime::operator ==(const DateTime & dateTime)
   {
@@ -84,6 +109,25 @@ namespace svn
     m_time = apr_date_parse_rfc(date);
     return IsValid();
   }
+
+  DateTime::operator QDateTime()const
+  {
+    QDateTime result;
+#if QT_VERSION < 0x040000
+    if (m_time<0)result.setTime_t(0,Qt::LocalTime);
+    else result.setTime_t(m_time/(1000*1000),Qt::LocalTime);
+#else
+    result.setTimeSpec(Qt::LocalTime);
+    if (m_time<0)result.setTime_t(0);
+    else result.setTime_t(m_time/(1000*1000));
+#endif
+    return result;
+  }
+  QString DateTime::toString(const QString&format)const
+  {
+    QDateTime dummy = *this;
+    return dummy.toString(format);
+  }
 }
 
 /* -----------------------------------------------------------------
