@@ -26,10 +26,15 @@
 #ifndef _SVNCPP_REVISION_HPP_
 #define _SVNCPP_REVISION_HPP_
 
+// svncpp
+#include <svnqt/datetime.hpp>
+#include <svnqt/svnqt_defines.hpp>
+
 // qt
 #include <qglobal.h>
 #if QT_VERSION < 0x040000
     #include <qstring.h>
+    #include <qtextstream.h>
 #else
     #include <QtCore>
 #endif
@@ -38,9 +43,6 @@
 #include "svn_types.h"
 #include "svn_opt.h"
 
-// svncpp
-#include "datetime.hpp"
-
 namespace svn
 {
   /**
@@ -48,7 +50,7 @@ namespace svn
    *
    * @see svn_opt_revnum_t
    */
-  class Revision
+  class SVNQT_EXPORT Revision
   {
   private:
     svn_opt_revision_t m_revision;
@@ -56,6 +58,12 @@ namespace svn
     void
     init (const svn_opt_revision_t * revision);
 
+    void
+    assign(const QString&);
+
+    void
+    assign(const QDateTime&);
+
   public:
     static const svn_opt_revision_kind START;
     static const svn_opt_revision_kind BASE;
@@ -87,6 +95,15 @@ namespace svn
      */
     Revision (const int revnum, const QString&revstring);
 
+    /**
+     * Constructor
+     * @param revstring a revision string
+     *
+     * The revision string MUST uppercase, it may some of "HEAD", "BASE", "WORKING", "COMMITED", "PREV",
+     * or a date in form {YYYY-MM-DD}.
+     */
+    Revision (const QString&revstring);
+
     /**
      * Constructor
      *
@@ -98,8 +115,15 @@ namespace svn
      * Constructor
      *
      * @param dateTime DateTime wrapper for apr_time_t
+     * @todo change it to referenced parameter (requires interface upgrade of lib)
      */
     Revision (const DateTime dateTime);
+    /**
+     * Constructor
+     *
+     * @param dateTime QDateTime type
+     */
+    Revision (const QDateTime&dateTime);
 
     /**
      * Copy constructor
@@ -144,6 +168,9 @@ namespace svn
     const svn_opt_revision_kind
     kind () const;
 
+    operator QString ()const;
+    QString toString()const;
+
     /**
      * @return date
      */
@@ -153,9 +180,28 @@ namespace svn
     bool operator==(const Revision&)const;
     bool operator!=(const svn_opt_revision_kind)const;
     bool operator==(const svn_opt_revision_kind)const;
+
+    bool operator!()const;
+    bool operator!();
+    operator bool()const;
+    operator bool();
+
+    /**
+     * assignment operator
+     * @param what a simple revision string (not s:e but s)
+     * @return object itself
+     */
+    Revision& operator=(const QString&what);
+
   };
 }
 
+inline QTextStream& operator<<(QTextStream&s,svn::Revision&r)
+{
+    s << r.toString();
+    return s;
+}
+
 #endif
 /* -----------------------------------------------------------------
  * local variables:
