@@ -26,6 +26,8 @@
 #ifndef _SVNCPP_TARGETS_HPP_
 #define _SVNCPP_TARGETS_HPP_
 
+#include "svnqt/svnqt_defines.hpp"
+
 #include <qglobal.h>
 #if QT_VERSION < 0x040000
 #include <qvaluelist.h>
@@ -53,7 +55,7 @@ namespace svn
   /**
    * Encapsulation for Subversion target arrays handling
    */
-  class Targets
+  class SVNQT_EXPORT Targets
   {
   public:
     /**
@@ -61,9 +63,14 @@ namespace svn
      *
      * @param targets vector of paths
      */
-
     Targets (const Pathes & targets);
 
+    /**
+     * Constructor
+     * @param path a single paths
+     */
+    Targets (const Path & targets);
+
     /**
      * Constructor from an APR array containing
      * char *.
